@@ -21,7 +21,6 @@ use std::ops::Bound::*;
 // between e.g. RTPS Reader and the application-facing DataReader. It keeps track of what each
 // DataReader has "read" or "taken".
 
-
 // helper function
 // somewhat like result.as_ref() , but one-sided only
 pub(crate) fn result_ok_as_ref_err_clone<T, E: Clone>(
@@ -105,7 +104,7 @@ where
 
     let new_instance_state = match new_sample {
       Ok(_) => InstanceState::Alive,
-      Err(_) => InstanceState::NotAlive_Disposed,
+      Err(_) => InstanceState::NotAliveDisposed,
     };
 
     // find or create metadata record
@@ -123,20 +122,18 @@ where
         self.instance_map.insert(instance_key.clone(), imd);
         self
           .hash_to_key_map
-          .insert(instance_key.into_hash_key(), instance_key.clone());
+          .insert(instance_key.hash_key(), instance_key.clone());
         self.instance_map.get_mut(&instance_key).unwrap() // must succeed, since this was just inserted
       }
     };
 
     // update instance metadata
-    instance_metadata
-      .instance_samples
-      .insert(receive_timestamp);
+    instance_metadata.instance_samples.insert(receive_timestamp);
 
     match (instance_metadata.instance_state, new_instance_state) {
       (InstanceState::Alive, _) => (), // was Alive, does not change counts
 
-      (InstanceState::NotAlive_Disposed, InstanceState::Alive) =>
+      (InstanceState::NotAliveDisposed, InstanceState::Alive) =>
       // born again
       {
         instance_metadata
@@ -144,9 +141,9 @@ where
           .disposed_generation_count += 1
       }
 
-      (InstanceState::NotAlive_Disposed, _) => (), // you can only die once
+      (InstanceState::NotAliveDisposed, _) => (), // you can only die once
 
-      (InstanceState::NotAlive_NoWriters, InstanceState::Alive) =>
+      (InstanceState::NotAliveNoWriters, InstanceState::Alive) =>
       // born again
       {
         instance_metadata
@@ -154,7 +151,7 @@ where
           .no_writers_generation_count += 1
       }
 
-      (InstanceState::NotAlive_NoWriters, _) => (), // you can only die once
+      (InstanceState::NotAliveNoWriters, _) => (), // you can only die once
     }
     instance_metadata.instance_state = new_instance_state;
 
@@ -274,7 +271,7 @@ where
           .contains( if d.sample_has_been_read { SampleState::Read } else {SampleState::NotRead} ) )
     &&
     // check view state
-    (*rc.view_state_mask() == ViewState::any() 
+    (*rc.view_state_mask() == ViewState::any()
       ||
       { let sample_gen = d.generation_counts.total();
         let last_accessed = imd.last_generation_accessed.total();
@@ -530,8 +527,11 @@ where
     match self.hash_to_key_map.get(&key_hash) {
       Some(k) => Some(k.clone()),
       None => {
-        debug!("get_key_by_hash: requested KeyHash {:?}, but not found. I have {:?}", 
-          key_hash, self.hash_to_key_map.keys() );
+        debug!(
+          "get_key_by_hash: requested KeyHash {:?}, but not found. I have {:?}",
+          key_hash,
+          self.hash_to_key_map.keys()
+        );
         None
       }
     }
