@@ -56,7 +56,7 @@ impl MessageReceiver {
     acknack_sender: mio_channel::SyncSender<(GuidPrefix, AckSubmessage)>,
   ) -> MessageReceiver {
     // could be passed in as a parameter
-    let locator_kind = LocatorKind::LOCATOR_KIND_UDPv4;
+    let locator_kind = LocatorKind::LOCATOR_KIND_UDP_V4;
 
     MessageReceiver {
       available_readers: BTreeMap::new(),
@@ -108,7 +108,7 @@ impl MessageReceiver {
   }
 
   pub fn add_reader(&mut self, new_reader: Reader) {
-    let eid = new_reader.get_guid().entityId;
+    let eid = new_reader.get_guid().entity_id;
     match self.available_readers.entry( eid ) {
       Entry::Occupied( _ ) => warn!("Already have Reader {:?} - not adding.",eid) ,
       e => { e.or_insert(new_reader); }
@@ -116,7 +116,7 @@ impl MessageReceiver {
   }
 
   pub fn remove_reader(&mut self, old_reader_guid: GUID) -> Option<Reader> {
-    self.available_readers.remove( &old_reader_guid.entityId )
+    self.available_readers.remove( &old_reader_guid.entity_id )
   }
 
   pub fn get_reader_mut(&mut self, reader_id: EntityId) -> Option<&mut Reader> {
@@ -223,10 +223,10 @@ impl MessageReceiver {
           for reader in self
             .available_readers
             .values_mut()
-            .filter(|r| r.contains_writer(data.writer_id) 
-                        // exception: discovery prococol reader must read from unkonwn discovery protocol writers
-                        // TODO: This logic here is uglyish. Can we just inject a presupposed writer (proxy)
-                        // to the built-in reader as it is created?
+            // exception: discovery prococol reader must read from unkonwn discovery protocol writers
+            // TODO: This logic here is uglyish. Can we just inject a presupposed writer (proxy)
+            // to the built-in reader as it is created?
+            .filter(|r| r.contains_writer(data.writer_id)
                         || (data.writer_id == EntityId::ENTITYID_SPDP_BUILTIN_PARTICIPANT_WRITER
                             &&
                             r.get_entity_id() == EntityId::ENTITYID_SPDP_BUILTIN_PARTICIPANT_READER
@@ -275,7 +275,7 @@ impl MessageReceiver {
         // Note: This must not block, because the receiving end is the same thread,
         // i.e. blocking here is an instant deadlock.
         match self.acknack_sender.try_send((self.source_guid_prefix, 
-            AckSubmessage::AckNack_Variant(acknack))) {
+            AckSubmessage::AckNack(acknack))) {
           Ok(_) => (),
           Err(TrySendError::Full(_)) => 
             info!("AckNack pipe full. Looks like I am very busy. Discarding submessage."),
@@ -335,7 +335,7 @@ impl MessageReceiver {
         }
       }
       InterpreterSubmessage::InfoDestination(info_dest, _flags) => {
-        if info_dest.guid_prefix != GUID::GUID_UNKNOWN.guidPrefix {
+        if info_dest.guid_prefix != GUID::GUID_UNKNOWN.guid_prefix {
           self.dest_guid_prefix = info_dest.guid_prefix;
         } else {
           self.dest_guid_prefix = self.own_guid_prefix;
@@ -437,7 +437,7 @@ use super::*;
       mio_channel::sync_channel::<(GuidPrefix, AckSubmessage)>(10);
     let mut message_receiver = MessageReceiver::new(guiPrefix, acknack_sender);
 
-    let entity = EntityId::createCustomEntityID([0, 0, 0], EntityKind::READER_WITH_KEY_USER_DEFINED);
+    let entity = EntityId::create_custom_entity_id([0, 0, 0], EntityKind::READER_WITH_KEY_USER_DEFINED);
     let new_guid = GUID::new_with_prefix_and_id(guiPrefix, entity);
 
     new_guid.from_prefix(entity);
@@ -448,9 +448,9 @@ use super::*;
 
     let dds_cache = Arc::new(RwLock::new(DDSCache::new()));
     dds_cache.write().unwrap().add_new_topic(
-      &"test".to_string(),
+      "test".to_string(),
       TopicKind::NoKey,
-      TypeDesc::new("testi"),
+      TypeDesc::new("testi".to_string()),
     );
     let reader_ing = ReaderIngredients {
       guid: new_guid,
@@ -462,7 +462,8 @@ use super::*;
     };
 
     let new_reader = Reader::new(reader_ing, dds_cache,
-      Rc::new(UDPSender::new_with_random_port().unwrap()));
+      Rc::new(UDPSender::new_with_random_port().unwrap()),
+      mio_extras::timer::Builder::default().build(),);
 
     // Skip for now+
     //new_reader.matched_writer_add(remote_writer_guid, mr_state);
@@ -474,14 +475,14 @@ use super::*;
 
     // this is not correct way to read history cache values but it serves as a test
     let sequenceNumbers =
-      message_receiver.get_reader_history_cache_start_and_end_seq_num(new_guid.entityId);
+      message_receiver.get_reader_history_cache_start_and_end_seq_num(new_guid.entity_id);
     info!(
       "history change sequence number range: {:?}",
       sequenceNumbers
     );
 
     let a = message_receiver
-      .get_reader_and_history_cache_change(new_guid.entityId, *sequenceNumbers.first().unwrap())
+      .get_reader_and_history_cache_change(new_guid.entity_id, *sequenceNumbers.first().unwrap())
       .unwrap();
     info!("reader history chache DATA: {:?}", a.data());
 
@@ -505,7 +506,7 @@ use super::*;
 
     let writer_ing = WriterIngredients {
       guid: GUID::new_with_prefix_and_id(guiPrefix, 
-          EntityId::createCustomEntityID([0, 0, 2], EntityKind::WRITER_WITH_KEY_USER_DEFINED)),
+          EntityId::create_custom_entity_id([0, 0, 2], EntityKind::WRITER_WITH_KEY_USER_DEFINED)),
       writer_command_receiver: hccc_download,
       topic_name: String::from("topicName1"),
       qos_policies: QosPolicies::qos_none(),
@@ -515,10 +516,11 @@ use super::*;
     let mut _writerObject = Writer::new(
       writer_ing,
       Arc::new(RwLock::new(DDSCache::new())),
-      Rc::new(UDPSender::new_with_random_port().unwrap())
+      Rc::new(UDPSender::new_with_random_port().unwrap()),
+      mio_extras::timer::Builder::default().build(),
     );
     let mut change = message_receiver.get_reader_and_history_cache_change_object(
-      new_guid.entityId,
+      new_guid.entity_id,
       *sequenceNumbers.first().unwrap(),
     );
     change.sequence_number = SequenceNumber::from(91);
@@ -550,7 +552,7 @@ use super::*;
     let guid_new = GUID::default();
     let (acknack_sender, _acknack_reciever) =
       mio_channel::sync_channel::<(GuidPrefix, AckSubmessage)>(10);
-    let mut message_receiver = MessageReceiver::new(guid_new.guidPrefix, acknack_sender);
+    let mut message_receiver = MessageReceiver::new(guid_new.guid_prefix, acknack_sender);
 
     message_receiver.handle_received_packet(udp_bits1);
     assert_eq!(message_receiver.submessage_count, 4);
@@ -562,7 +564,7 @@ use super::*;
   #[test]
   fn mr_test_header() {
     let guid_new = GUID::default();
-    let header = Header::new(guid_new.guidPrefix);
+    let header = Header::new(guid_new.guid_prefix);
 
     let bytes = header.write_to_vec().unwrap();
     let new_header = Header::read_from_buffer(&bytes).unwrap();
