@@ -4,14 +4,10 @@ use serde::{de::DeserializeOwned};
 use mio::{Poll, Token, Ready, PollOpt, Evented};
 
 use crate::{
-  structure::{
-    entity::RTPSEntity ,
-  },
+  structure::{entity::RTPSEntity},
 };
 use crate::dds::{
-  traits::serde_adapters::no_key::*, 
-  values::result::*, qos::*,
-  readcondition::*, data_types::*, 
+  traits::serde_adapters::no_key::*, values::result::*, qos::*, readcondition::*, data_types::*,
 };
 
 use crate::dds::with_key::datareader as datareader_with_key;
@@ -44,13 +40,10 @@ use super::{
 /// struct SomeType {}
 ///
 /// // NoKey is important
-/// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+/// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
 /// let data_reader = subscriber.create_datareader_no_key::<SomeType, CDRDeserializerAdapter<_>>(topic, None);
 /// ```
-pub struct DataReader<
-  D: DeserializeOwned,
-  DA: DeserializerAdapter<D> = CDRDeserializerAdapter<D>,
-> {
+pub struct DataReader<D: DeserializeOwned, DA: DeserializerAdapter<D> = CDRDeserializerAdapter<D>> {
   keyed_datareader: datareader_with_key::DataReader<NoKeyWrapper<D>, DAWrapper<DA>>,
 }
 
@@ -91,7 +84,7 @@ where
   /// # let subscriber = domain_participant.create_subscriber(&qos).unwrap();
   /// #
   /// # // NoKey is important
-  /// # let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+  /// # let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// #
   /// # #[derive(Serialize, Deserialize)]
   /// # struct SomeType {}
@@ -138,7 +131,7 @@ where
   /// # let subscriber = domain_participant.create_subscriber(&qos).unwrap();
   /// #
   /// # // NoKey is important
-  /// # let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+  /// # let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// #
   /// # #[derive(Serialize, Deserialize)]
   /// # struct SomeType {}
@@ -179,7 +172,7 @@ where
   /// # let subscriber = domain_participant.create_subscriber(&qos).unwrap();
   /// #
   /// # // NoKey is important
-  /// # let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+  /// # let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// #
   /// # #[derive(Serialize, Deserialize)]
   /// # struct SomeType {}
@@ -211,7 +204,7 @@ where
   /// # let subscriber = domain_participant.create_subscriber(&qos).unwrap();
   /// #
   /// # // NoKey is important
-  /// # let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+  /// # let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// #
   /// # #[derive(Serialize, Deserialize)]
   /// # struct SomeType {}
@@ -247,7 +240,7 @@ where
   /// # let subscriber = domain_participant.create_subscriber(&qos).unwrap();
   /// #
   /// # // NoKey is important
-  /// # let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+  /// # let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// #
   /// # #[derive(Serialize, Deserialize)]
   /// # struct SomeType {}
@@ -285,7 +278,7 @@ where
   /// # let subscriber = domain_participant.create_subscriber(&qos).unwrap();
   /// #
   /// # // NoKey is important
-  /// # let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+  /// # let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// #
   /// # #[derive(Serialize, Deserialize)]
   /// # struct SomeType {}
@@ -329,7 +322,7 @@ where
   /// # let subscriber = domain_participant.create_subscriber(&qos).unwrap();
   /// #
   /// # // NoKey is important
-  /// # let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+  /// # let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// #
   /// # #[derive(Serialize, Deserialize)]
   /// # struct SomeType {}
@@ -369,7 +362,7 @@ where
   /// # let subscriber = domain_participant.create_subscriber(&qos).unwrap();
   /// #
   /// # // NoKey is important
-  /// # let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+  /// # let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// #
   /// # #[derive(Serialize, Deserialize)]
   /// # struct SomeType {}
@@ -409,7 +402,7 @@ where
   /// # let subscriber = domain_participant.create_subscriber(&qos).unwrap();
   /// #
   /// # // NoKey is important
-  /// # let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+  /// # let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// #
   /// # #[derive(Serialize, Deserialize)]
   /// # struct SomeType {}
