@@ -2,13 +2,9 @@ use std::{
   time::{Duration},
 };
 
-
 use serde::Serialize;
 
-use crate::{
-  serialization::CDRSerializerAdapter, 
-  structure::time::Timestamp,
-};
+use crate::{serialization::CDRSerializerAdapter, structure::time::Timestamp};
 use crate::structure::entity::{RTPSEntity};
 
 use crate::dds::pubsub::Publisher;
@@ -49,7 +45,7 @@ use super::wrappers::{NoKeyWrapper, SAWrapper};
 /// struct SomeType {}
 ///
 /// // NoKey is important
-/// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+/// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
 /// let data_writer = publisher.create_datawriter_no_key::<SomeType, CDRSerializerAdapter<_>>(topic, None);
 /// ```
 pub struct DataWriter<D: Serialize, SA: SerializerAdapter<D> = CDRSerializerAdapter<D>> {
@@ -89,7 +85,7 @@ where
   /// # struct SomeType {}
   /// #
   /// // NoKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// let data_writer = publisher.create_datawriter_no_key::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// let some_data = SomeType {};
@@ -122,7 +118,7 @@ where
   /// # struct SomeType {}
   /// #
   /// // NoKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// let data_writer = publisher.create_datawriter_no_key::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// data_writer.wait_for_acknowledgments(Duration::from_millis(100));
@@ -153,7 +149,7 @@ where
   /// # struct SomeType {}
   /// #
   /// // NoKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// let data_writer = publisher.create_datawriter_no_key::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// if let Ok(status) = data_writer.get_liveliness_lost_status() {
@@ -185,7 +181,7 @@ where
   /// # struct SomeType {}
   /// #
   /// // NoKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// let data_writer = publisher.create_datawriter_no_key::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// if let Ok(odl_status) = data_writer.get_offered_deadline_missed_status() {
@@ -217,7 +213,7 @@ where
   /// # struct SomeType {}
   /// #
   /// // NoKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// let data_writer = publisher.create_datawriter_no_key::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// if let Ok(status) = data_writer.get_offered_incompatible_qos_status() {
@@ -249,7 +245,7 @@ where
   /// # struct SomeType {}
   /// #
   /// // NoKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// let data_writer = publisher.create_datawriter_no_key::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// if let Ok(status) = data_writer.get_publication_matched_status() {
@@ -280,7 +276,7 @@ where
   /// # struct SomeType {}
   /// #
   /// // NoKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// let data_writer = publisher.create_datawriter_no_key::<SomeType, CDRSerializerAdapter<_>>(topic.clone(), None).unwrap();
   ///
   /// assert_eq!(&topic, data_writer.get_topic());
@@ -309,7 +305,7 @@ where
   /// # struct SomeType {}
   /// #
   /// // NoKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// let data_writer = publisher.create_datawriter_no_key::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// assert_eq!(&publisher, data_writer.get_publisher());
@@ -338,7 +334,7 @@ where
   /// # struct SomeType {}
   /// #
   /// // NoKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// let data_writer = publisher.create_datawriter_no_key::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// data_writer.assert_liveliness();
@@ -368,7 +364,7 @@ where
   /// # struct SomeType {}
   /// #
   /// // NoKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// let data_writer = publisher.create_datawriter_no_key::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// for sub in data_writer.get_matched_subscriptions().iter() {
@@ -380,7 +376,7 @@ where
   }
   /*
   /// Gets mio receiver for all implemented Status changes
-  ///  
+  ///
   /// # Examples
   ///
   /// ```
@@ -399,7 +395,7 @@ where
   /// # struct SomeType {}
   /// #
   /// // NoKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::NoKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// let data_writer = publisher.create_datawriter_no_key::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// // Some status has changed
@@ -448,7 +444,12 @@ mod tests {
       .create_publisher(&qos)
       .expect("Failed to create publisher");
     let topic = domain_participant
-      .create_topic("Aasii", "Huh?", &qos, TopicKind::NoKey)
+      .create_topic(
+        "Aasii".to_string(),
+        "Huh?".to_string(),
+        &qos,
+        TopicKind::NoKey,
+      )
       .expect("Failed to create topic");
 
     let data_writer: DataWriter<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>> =
@@ -483,7 +484,12 @@ mod tests {
       .create_publisher(&qos)
       .expect("Failed to create publisher");
     let topic = domain_participant
-      .create_topic("Aasii", "Huh?", &qos, TopicKind::NoKey)
+      .create_topic(
+        "Aasii".to_string(),
+        "Huh?".to_string(),
+        &qos,
+        TopicKind::NoKey,
+      )
       .expect("Failed to create topic");
 
     let data_writer: DataWriter<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>> =
@@ -501,6 +507,6 @@ mod tests {
     let res = data_writer
       .wait_for_acknowledgments(Duration::from_secs(2))
       .unwrap();
-    assert_eq!(res, true); // no "Reliable" QoS policy => "succeeds" immediately 
+    assert!(res); // no "Reliable" QoS policy => "succeeds" immediately
   }
 }
