@@ -38,9 +38,9 @@ use super::dp_event_loop::DomainInfo;
 /// DDS DomainParticipant generally only one per domain per machine should be
 /// active
 #[derive(Clone)]
-// This is a smart pointer for DomainParticipant_Inner for easier manipulation.
+// This is a smart pointer for DomainParticipantInner for easier manipulation.
 pub struct DomainParticipant {
-  dpi: Arc<Mutex<DomainParticipant_Disc>>,
+  dpi: Arc<Mutex<DomainParticipantDisc>>,
 }
 
 #[allow(clippy::new_without_default)]
@@ -57,7 +57,7 @@ impl DomainParticipant {
     // so its .drop() can wait until discovery has had a chance to stop.
     let (djh_sender, djh_receiver) = mio_channel::channel();
 
-    let mut dpd = DomainParticipant_Disc::new(domain_id, djh_receiver)?;
+    let mut dpd = DomainParticipantDisc::new(domain_id, djh_receiver)?;
 
     let discovery_updated_sender = match dpd.discovery_updated_sender.take() {
       Some(dus) => dus,
@@ -83,19 +83,22 @@ impl DomainParticipant {
     let disc_db_clone = dp.discovery_db();
     let discovery_handle = thread::Builder::new()
       .name("RustDDS discovery thread".to_string())
-      .spawn(move || { 
-          match Discovery::new(
-              dp_clone,
-              disc_db_clone,
-              discovery_started_sender,
-              discovery_updated_sender,
-              discovery_command_receiver,
-            ) {
-            Ok(mut discovery) => // run the event loop
-              discovery.discovery_event_loop(),
-            Err(_) => (),
+      .spawn(move || {
+        match Discovery::new(
+          dp_clone,
+          disc_db_clone,
+          discovery_started_sender,
+          discovery_updated_sender,
+          discovery_command_receiver,
+        ) {
+          Ok(mut discovery) =>
+          // run the event loop
+          {
+            discovery.discovery_event_loop()
           }
-        })?;
+          Err(_) => (),
+        }
+      })?;
 
     djh_sender.send(discovery_handle).unwrap_or(()); // send join handle to inner participant
 
@@ -175,12 +178,12 @@ impl DomainParticipant {
   ///
   /// let domain_participant = DomainParticipant::new(0).unwrap();
   /// let qos = QosPolicyBuilder::new().build();
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::WithKey);
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey);
   /// ```
   pub fn create_topic(
     &self,
-    name: &str,
-    type_desc: &str,
+    name: String,
+    type_desc: String,
     qos: &QosPolicies,
     topic_kind: TopicKind,
   ) -> Result<Topic> {
@@ -270,7 +273,6 @@ impl DomainParticipant {
       .discovery_db
       .clone()
   }
-
 }
 
 impl PartialEq for DomainParticipant {
@@ -283,7 +285,7 @@ impl PartialEq for DomainParticipant {
 
 #[derive(Clone)]
 pub struct DomainParticipantWeak {
-  dpi: Weak<Mutex<DomainParticipant_Disc>>,
+  dpi: Weak<Mutex<DomainParticipantDisc>>,
   // This struct caches the GUID to avoid construction deadlocks
   guid: GUID,
 }
@@ -312,8 +314,8 @@ impl DomainParticipantWeak {
 
   pub fn create_topic(
     &self,
-    name: &str,
-    type_desc: &str,
+    name: String,
+    type_desc: String,
     qos: &QosPolicies,
     topic_kind: TopicKind,
   ) -> Result<Topic> {
@@ -370,8 +372,8 @@ impl RTPSEntity for DomainParticipantWeak {
 
 // This struct exists only to control and stop Discovery when DomainParticipant
 // should be dropped
-pub(crate) struct DomainParticipant_Disc {
-  dpi: Arc<Mutex<DomainParticipant_Inner>>,
+pub(crate) struct DomainParticipantDisc {
+  dpi: Arc<Mutex<DomainParticipantInner>>,
   // Discovery control
   discovery_updated_sender: Option<mio_channel::SyncSender<DiscoveryNotificationType>>,
   discovery_command_receiver: Option<mio_channel::Receiver<DiscoveryCommand>>,
@@ -379,20 +381,20 @@ pub(crate) struct DomainParticipant_Disc {
   discovery_join_handle: mio_channel::Receiver<JoinHandle<()>>,
 }
 
-impl DomainParticipant_Disc {
+impl DomainParticipantDisc {
   pub fn new(
     domain_id: u16,
     discovery_join_handle: mio_channel::Receiver<JoinHandle<()>>,
-  ) -> Result<DomainParticipant_Disc> {
+  ) -> Result<DomainParticipantDisc> {
     let (discovery_update_notification_sender, discovery_update_notification_receiver) =
       mio_channel::sync_channel::<DiscoveryNotificationType>(100);
 
-    let dpi = DomainParticipant_Inner::new(domain_id, discovery_update_notification_receiver)?;
+    let dpi = DomainParticipantInner::new(domain_id, discovery_update_notification_receiver)?;
 
     let (discovery_command_sender, discovery_command_receiver) =
       mio_channel::sync_channel::<DiscoveryCommand>(10);
 
-    Ok(DomainParticipant_Disc {
+    Ok(DomainParticipantDisc {
       dpi: Arc::new(Mutex::new(dpi)),
       discovery_updated_sender: Some(discovery_update_notification_sender),
       discovery_command_receiver: Some(discovery_command_receiver),
@@ -428,8 +430,8 @@ impl DomainParticipant_Disc {
   pub fn create_topic(
     &self,
     dp: &DomainParticipantWeak,
-    name: &str,
-    type_desc: &str,
+    name: String,
+    type_desc: String,
     qos: &QosPolicies,
     topic_kind: TopicKind,
   ) -> Result<Topic> {
@@ -476,20 +478,19 @@ impl DomainParticipant_Disc {
     // by writers with that particular QoS.
     self
       .discovery_command_channel
-      .send(DiscoveryCommand::MANUAL_ASSERT_LIVELINESS)
+      .send(DiscoveryCommand::ManualAssertLiveliness)
       .or_else(|e| {
         log_and_err_internal!("assert_liveness - Failed to send DiscoveryCommand. {:?}", e)
       })
   }
-
 }
 
-impl Drop for DomainParticipant_Disc {
+impl Drop for DomainParticipantDisc {
   fn drop(&mut self) {
     debug!("Sending Discovery Stop signal.");
     match self
       .discovery_command_channel
-      .send(DiscoveryCommand::STOP_DISCOVERY)
+      .send(DiscoveryCommand::StopDiscovery)
     {
       Ok(_) => (),
       _ => {
@@ -507,7 +508,7 @@ impl Drop for DomainParticipant_Disc {
 }
 
 // This is the actual working DomainParticipant.
-pub(crate) struct DomainParticipant_Inner {
+pub(crate) struct DomainParticipantInner {
   domain_id: u16,
   participant_id: u16,
 
@@ -532,15 +533,10 @@ pub(crate) struct DomainParticipant_Inner {
 
   dds_cache: Arc<RwLock<DDSCache>>,
   discovery_db: Arc<RwLock<DiscoveryDB>>,
-
 }
 
-impl Drop for DomainParticipant_Inner {
+impl Drop for DomainParticipantInner {
   fn drop(&mut self) {
-    if std::thread::panicking() {
-      error!("PANIC in dp_event_loop!")
-    }
-
     // if send has an error simply leave as we have lost control of the
     // ev_loop_thread anyways
     match self.stop_poll_sender.send(()) {
@@ -556,7 +552,7 @@ impl Drop for DomainParticipant_Inner {
           .unwrap_or_else(|e| warn!("Failed to join dp_event_loop: {:?}", e));
       }
       None => {
-        error!("Someone managed to steal dp_event_loop join handle from DomainParticipant_Inner.");
+        error!("Someone managed to steal dp_event_loop join handle from DomainParticipantInner.");
       }
     }
     debug!("Joined dp_event_loop");
@@ -564,25 +560,25 @@ impl Drop for DomainParticipant_Inner {
 }
 
 #[allow(clippy::new_without_default)]
-impl DomainParticipant_Inner {
+impl DomainParticipantInner {
   fn new(
     domain_id: u16,
     discovery_update_notification_receiver: mio_channel::Receiver<DiscoveryNotificationType>,
-  ) -> Result<DomainParticipant_Inner> {
+  ) -> Result<DomainParticipantInner> {
     let mut listeners = HashMap::new();
 
     match UDPListener::new_multicast(
-        DISCOVERY_SENDER_TOKEN,
-        "0.0.0.0",
-        get_spdp_well_known_multicast_port(domain_id),
-        Ipv4Addr::new(239, 255, 0, 1) ) 
-    {
-      Ok(l) => { listeners.insert(DISCOVERY_MUL_LISTENER_TOKEN, l); }
-      Err(e) =>
-        warn!("Cannot get multicast discovery listener: {:?}",e),
+      DISCOVERY_SENDER_TOKEN,
+      "0.0.0.0",
+      get_spdp_well_known_multicast_port(domain_id),
+      Ipv4Addr::new(239, 255, 0, 1),
+    ) {
+      Ok(l) => {
+        listeners.insert(DISCOVERY_MUL_LISTENER_TOKEN, l);
+      }
+      Err(e) => warn!("Cannot get multicast discovery listener: {:?}", e),
     }
 
-
     let mut participant_id = 0;
 
     let mut discovery_listener = None;
@@ -590,10 +586,11 @@ impl DomainParticipant_Inner {
     // Magic value 120 below is from RTPS spec Section "9.6.1.3 Default Port Numbers"
     while discovery_listener.is_none() && participant_id < 120 {
       discovery_listener = UDPListener::new_unicast(
-          DISCOVERY_SENDER_TOKEN,
-          "0.0.0.0",
-          get_spdp_well_known_unicast_port(domain_id, participant_id),
-        ).ok();
+        DISCOVERY_SENDER_TOKEN,
+        "0.0.0.0",
+        get_spdp_well_known_unicast_port(domain_id, participant_id),
+      )
+      .ok();
       if discovery_listener.is_none() {
         participant_id += 1;
       }
@@ -611,34 +608,36 @@ impl DomainParticipant_Inner {
     // Now the user traffic listeners
 
     match UDPListener::new_multicast(
-        USER_TRAFFIC_SENDER_TOKEN,
+      USER_TRAFFIC_SENDER_TOKEN,
       "0.0.0.0",
       get_user_traffic_multicast_port(domain_id),
-      Ipv4Addr::new(239, 255, 0, 1) )
-    {
-      Ok(l) => { listeners.insert(USER_TRAFFIC_MUL_LISTENER_TOKEN, l); }
-      Err(e) =>
-        warn!("Cannot get multicast discovery listener: {:?}",e),
+      Ipv4Addr::new(239, 255, 0, 1),
+    ) {
+      Ok(l) => {
+        listeners.insert(USER_TRAFFIC_MUL_LISTENER_TOKEN, l);
+      }
+      Err(e) => warn!("Cannot get multicast discovery listener: {:?}", e),
     }
 
-
     let user_traffic_listener = UDPListener::new_unicast(
-            USER_TRAFFIC_SENDER_TOKEN,
-            "0.0.0.0",
-            get_user_traffic_unicast_port(domain_id, participant_id),
-          );
+      USER_TRAFFIC_SENDER_TOKEN,
+      "0.0.0.0",
+      get_user_traffic_unicast_port(domain_id, participant_id),
+    );
     let user_traffic_listener = match user_traffic_listener {
-          Ok(l) => l,
-          Err(e) => return log_and_err_internal!("Could not open user traffic listener: {:?}",e),
-        };
+      Ok(l) => l,
+      Err(e) => return log_and_err_internal!("Could not open user traffic listener: {:?}", e),
+    };
     listeners.insert(USER_TRAFFIC_LISTENER_TOKEN, user_traffic_listener);
 
     // Adding readers
-    let (sender_add_reader, receiver_add_reader) = mio_channel::sync_channel::<ReaderIngredients>(100);
+    let (sender_add_reader, receiver_add_reader) =
+      mio_channel::sync_channel::<ReaderIngredients>(100);
     let (sender_remove_reader, receiver_remove_reader) = mio_channel::sync_channel::<GUID>(10);
 
     // Writers
-    let (add_writer_sender, add_writer_receiver) = mio_channel::sync_channel::<WriterIngredients>(10);
+    let (add_writer_sender, add_writer_receiver) =
+      mio_channel::sync_channel::<WriterIngredients>(10);
     let (remove_writer_sender, remove_writer_receiver) = mio_channel::sync_channel::<GUID>(10);
 
     let new_guid = GUID::new_particiapnt_guid();
@@ -658,14 +657,14 @@ impl DomainParticipant_Inner {
     let dds_cache_clone = dds_cache.clone();
     let disc_db_clone = discovery_db.clone();
     let ev_loop_handle = thread::Builder::new()
-      .name(format!("RustDDS Participant {} event loop",participant_id))
-      .spawn(move || { 
+      .name(format!("RustDDS Participant {} event loop", participant_id))
+      .spawn(move || {
         let dp_event_loop = DPEventLoop::new(
           domain_info,
           listeners,
           dds_cache_clone,
           disc_db_clone,
-          new_guid.guidPrefix,
+          new_guid.guid_prefix,
           TokenReceiverPair {
             token: ADD_READER_TOKEN,
             receiver: receiver_add_reader,
@@ -685,13 +684,14 @@ impl DomainParticipant_Inner {
           stop_poll_receiver,
           discovery_update_notification_receiver,
         );
-
         dp_event_loop.event_loop()
       })?;
 
-    info!("New DomainParticipant_Inner: domain_id={:?} participant_id={:?} GUID={:?}",
-      domain_id, participant_id, new_guid);
-    Ok(DomainParticipant_Inner {
+    info!(
+      "New DomainParticipantInner: domain_id={:?} participant_id={:?} GUID={:?}",
+      domain_id, participant_id, new_guid
+    );
+    Ok(DomainParticipantInner {
       domain_id,
       participant_id,
       my_guid: new_guid,
@@ -769,8 +769,8 @@ impl DomainParticipant_Inner {
   pub fn create_topic(
     &self,
     domain_participant_weak: &DomainParticipantWeak,
-    name: &str,
-    type_desc: &str,
+    name: String,
+    type_desc: String,
     qos: &QosPolicies,
     topic_kind: TopicKind,
   ) -> Result<Topic> {
@@ -826,7 +826,7 @@ impl DomainParticipant_Inner {
         let name = d.get_topic_name().clone();
         let type_desc = d.topic_data.type_name.clone();
         let topic =
-          self.create_topic(domain_participant_weak, &name, &type_desc, &qos, topic_kind)?;
+          self.create_topic(domain_participant_weak, name, type_desc, &qos, topic_kind)?;
         Ok(Some(topic))
       }
       None => Ok(None),
@@ -882,13 +882,13 @@ impl RTPSEntity for DomainParticipant {
   }
 }
 
-impl RTPSEntity for DomainParticipant_Disc {
+impl RTPSEntity for DomainParticipantDisc {
   fn get_guid(&self) -> GUID {
     self.dpi.lock().unwrap().get_guid()
   }
 }
 
-impl RTPSEntity for DomainParticipant_Inner {
+impl RTPSEntity for DomainParticipantInner {
   fn get_guid(&self) -> GUID {
     self.my_guid
   }
@@ -928,7 +928,7 @@ mod tests {
   };
   use super::DomainParticipant;
 
-  use speedy::{Endianness,Writable};
+  use speedy::{Endianness, Writable};
 
   use crate::serialization::cdr_serializer::CDRSerializerAdapter;
   use byteorder::LittleEndian;
@@ -956,7 +956,12 @@ mod tests {
       .expect("Failed to create publisher");
 
     let topic = domain_participant
-      .create_topic("Aasii", "RandomData", &qos.clone(), TopicKind::WithKey)
+      .create_topic(
+        "Aasii".to_string(),
+        "RandomData".to_string(),
+        &qos.clone(),
+        TopicKind::WithKey,
+      )
       .expect("Failed to create topic");
 
     let mut _data_writer = publisher
@@ -977,14 +982,19 @@ mod tests {
       .expect("Failed to create publisher");
 
     let topic = domain_participant
-      .create_topic("Aasii", "Huh?", &qos.clone(), TopicKind::WithKey)
+      .create_topic(
+        "Aasii".to_string(),
+        "Huh?".to_string(),
+        &qos.clone(),
+        TopicKind::WithKey,
+      )
       .expect("Failed to create topic");
 
     let mut _data_writer = publisher
       .create_datawriter::<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>>(topic, None)
       .expect("Failed to create datawriter");
 
-    let portNumber: u16 = get_user_traffic_unicast_port(5, 0);
+    let port_number: u16 = get_user_traffic_unicast_port(5, 0);
     let sender = UDPSender::new(1234).unwrap();
     let mut m: Message = Message::default();
 
@@ -1012,15 +1022,15 @@ mod tests {
       protocol_id: ProtocolId::default(),
       protocol_version: ProtocolVersion { major: 2, minor: 3 },
       vendor_id: VendorId::THIS_IMPLEMENTATION,
-      guid_prefix: GUID::default().guidPrefix,
+      guid_prefix: GUID::default().guid_prefix,
     };
     m.set_header(h);
     m.add_submessage(SubMessage::from(s));
     let _data: Vec<u8> = m.write_to_vec_with_ctx(Endianness::LittleEndian).unwrap();
     info!("data to send via udp: {:?}", _data);
     let loca = Locator {
-      kind: LocatorKind::LOCATOR_KIND_UDPv4,
-      port: portNumber as u32,
+      kind: LocatorKind::LOCATOR_KIND_UDP_V4,
+      port: port_number as u32,
       address: [
         0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
         0x00,
