@@ -7,7 +7,6 @@ use crate::{
 
 pub use crate::structure::topic_kind::TopicKind;
 
-
 /// Trait estimate of DDS 2.2.2.3.1 TopicDescription Class
 pub trait TopicDescription {
   fn get_participant(&self) -> Option<DomainParticipant>;
@@ -28,7 +27,7 @@ pub trait TopicDescription {
 /// let domain_participant = DomainParticipant::new(0).unwrap();
 /// let qos = QosPolicyBuilder::new().build();
 /// let topic = domain_participant
-///       .create_topic("some_topic", "SomeType", &qos, TopicKind::WithKey)
+///       .create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey)
 ///       .unwrap();
 /// ```
 #[derive(Clone)]
@@ -46,8 +45,14 @@ impl Topic {
     my_qos_policies: &QosPolicies,
     topic_kind: TopicKind,
   ) -> Topic {
-    Topic { 
-      inner: Arc::new(InnerTopic::new(my_domainparticipant,my_name, my_typedesc, my_qos_policies, topic_kind) )
+    Topic {
+      inner: Arc::new(InnerTopic::new(
+        my_domainparticipant,
+        my_name,
+        my_typedesc,
+        my_qos_policies,
+        topic_kind,
+      )),
     }
   }
 
@@ -77,7 +82,7 @@ impl Topic {
   /// # let domain_participant = DomainParticipant::new(0).unwrap();
   /// # let qos = QosPolicyBuilder::new().build();
   /// let topic = domain_participant
-  ///     .create_topic("some_topic", "SomeType", &qos, TopicKind::WithKey)
+  ///     .create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey)
   ///     .unwrap();
   /// assert_eq!(topic.kind(), TopicKind::WithKey);
   /// ```
@@ -132,8 +137,6 @@ impl HasQoSPolicy for Topic {
 
 //impl DDSEntity for Topic {}
 
-
-
 // -------------------------------- InnerTopic -----------------------------
 
 #[derive(Clone)]
