@@ -50,7 +50,7 @@ use crate::{discovery::data_types::topic_data::SubscriptionBuiltinTopicData, dds
 use super::super::{datasample_cache::DataSampleCache, writer::WriterCommand, };
 
 /// Simplified type for CDR encoding
-pub type DataWriter_CDR<D> = DataWriter<D,CDRSerializerAdapter<D>>;
+pub type DataWriterCdr<D> = DataWriter<D,CDRSerializerAdapter<D>>;
 
 /// DDS DataWriter for keyed topics
 ///
@@ -80,7 +80,7 @@ pub type DataWriter_CDR<D> = DataWriter<D,CDRSerializerAdapter<D>>;
 /// }
 ///
 /// // WithKey is important
-/// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::WithKey).unwrap();
+/// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
 /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None);
 /// ```
 pub struct DataWriter<D: Keyed + Serialize, SA: SerializerAdapter<D> = CDRSerializerAdapter<D>>
@@ -105,7 +105,7 @@ where
   fn drop(&mut self) {
     match self
       .discovery_command
-      .send(DiscoveryCommand::REMOVE_LOCAL_WRITER {
+      .send(DiscoveryCommand::RemoveLocalWriter {
         guid: self.get_guid(),
       }) {
       Ok(_) => {}
@@ -136,7 +136,7 @@ where
     status_receiver_rec: Receiver<DataWriterStatus>,
   ) -> Result<DataWriter<D, SA>> {
     let entity_id = match guid {
-      Some(g) => g.entityId,
+      Some(g) => g.entity_id,
       None => EntityId::ENTITYID_UNKNOWN,
     };
 
@@ -150,7 +150,7 @@ where
 
     match dds_cache.write() {
       Ok(mut cache) => cache.add_new_topic(
-        &topic.get_name(),
+        topic.get_name(),
         TopicKind::NoKey,
         topic.get_type(),
       ),
@@ -160,7 +160,7 @@ where
     if let Some(lv) = topic.get_qos().liveliness { match lv {
       Liveliness::Automatic { lease_duration: _ } => (),
       Liveliness::ManualByParticipant { lease_duration: _ } => {
-        match discovery_command.send(DiscoveryCommand::MANUAL_ASSERT_LIVELINESS) {
+        match discovery_command.send(DiscoveryCommand::ManualAssertLiveliness) {
           Ok(_) => (),
           Err(e) => {
             error!("Failed to send DiscoveryCommand - Refresh. {:?}", e);
@@ -216,7 +216,7 @@ where
   /// }
   ///
   /// // WithKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::WithKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
   /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// data_writer.refresh_manual_liveliness();
@@ -229,7 +229,7 @@ where
       Liveliness::ManualByParticipant { lease_duration: _ } => {
         match self
           .discovery_command
-          .send(DiscoveryCommand::MANUAL_ASSERT_LIVELINESS)
+          .send(DiscoveryCommand::ManualAssertLiveliness)
         {
           Ok(_) => (),
           Err(e) => {
@@ -269,7 +269,7 @@ where
   /// }
   ///
   /// // WithKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::WithKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
   /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// let some_data = SomeType { a: 1 };
@@ -277,9 +277,9 @@ where
   /// ```
   pub fn write(&self, data: D, source_timestamp: Option<Timestamp>) -> Result<()> {
 
-    let send_buffer = SA::to_Bytes( &data )?; // serialize
+    let send_buffer = SA::to_bytes( &data )?; // serialize
 
-    let ddsdata = DDSData::new( SerializedPayload::new_from_Bytes( SA::output_encoding() , send_buffer) );
+    let ddsdata = DDSData::new( SerializedPayload::new_from_bytes( SA::output_encoding() , send_buffer) );
     let writer_command = WriterCommand::DDSData { data: ddsdata , source_timestamp };
 
     let timeout =
@@ -343,7 +343,7 @@ where
   /// }
   ///
   /// // WithKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::WithKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
   /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// let some_data = SomeType { a: 1 };
@@ -404,7 +404,7 @@ where
   /// }
   ///
   /// // WithKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::WithKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
   /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// // Some status has changed
@@ -454,7 +454,7 @@ where
   /// }
   ///
   /// // WithKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::WithKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
   /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// // Liveliness lost status has changed
@@ -495,7 +495,7 @@ where
   /// }
   ///
   /// // WithKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::WithKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
   /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// // Deadline missed status has changed
@@ -555,7 +555,7 @@ where
   /// }
   ///
   /// // WithKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::WithKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
   /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// // Liveliness lost status has changed
@@ -597,7 +597,7 @@ where
   /// }
   ///
   /// // WithKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::WithKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
   /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// // Liveliness lost status has changed
@@ -640,7 +640,7 @@ where
   /// }
   ///
   /// // WithKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::WithKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
   /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic.clone(), None).unwrap();
   ///
   /// assert_eq!(data_writer.get_topic(), &topic);
@@ -677,7 +677,7 @@ where
   /// }
   ///
   /// // WithKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::WithKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
   /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// assert_eq!(data_writer.get_publisher(), &publisher);
@@ -713,7 +713,7 @@ where
   /// }
   ///
   /// // WithKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::WithKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
   /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// data_writer.assert_liveliness().unwrap();
@@ -727,7 +727,7 @@ where
     match self.get_qos().liveliness {
       Some(Liveliness::ManualByTopic { lease_duration: _ }) => {
         self.discovery_command
-          .send(DiscoveryCommand::ASSERT_TOPIC_LIVELINESS {
+          .send(DiscoveryCommand::AssertTopicLiveliness {
             writer_guid: self.get_guid(),
             manual_assertion: true, // by definition of this function
             })
@@ -767,7 +767,7 @@ where
   /// }
   ///
   /// // WithKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::WithKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
   /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// for sub in data_writer.get_matched_subscriptions().iter() {
@@ -810,7 +810,7 @@ where
   /// }
   ///
   /// // WithKey is important
-  /// let topic = domain_participant.create_topic("some_topic", "SomeType", &qos, TopicKind::WithKey).unwrap();
+  /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
   /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
   /// let some_data_1_1 = SomeType { a: 1, val: 3};
@@ -829,11 +829,11 @@ where
   /// ```
   pub fn dispose(&self, key: <D as Keyed>::K, source_timestamp: Option<Timestamp>) -> Result<()> {
 
-    let send_buffer = SA::key_to_Bytes( &key  )?; // serialize key
+    let send_buffer = SA::key_to_bytes( &key  )?; // serialize key
 
     let ddsdata = DDSData::new_disposed_by_key( 
       ChangeKind::NotAliveDisposed,
-      SerializedPayload::new_from_Bytes( SA::output_encoding() , send_buffer) 
+      SerializedPayload::new_from_bytes( SA::output_encoding() , send_buffer) 
     );
     self.cc_upload
       .send(WriterCommand::DDSData { data: ddsdata , source_timestamp })
@@ -912,7 +912,7 @@ mod tests {
       .create_publisher(&qos)
       .expect("Failed to create publisher");
     let topic = domain_participant
-      .create_topic("Aasii", "Huh?", &qos, TopicKind::WithKey)
+      .create_topic("Aasii".to_string(), "Huh?".to_string(), &qos, TopicKind::WithKey)
       .expect("Failed to create topic");
 
     let data_writer: DataWriter<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>> =
@@ -947,7 +947,7 @@ mod tests {
       .create_publisher(&qos)
       .expect("Failed to create publisher");
     let topic = domain_participant
-      .create_topic("Aasii", "Huh?", &qos, TopicKind::WithKey)
+      .create_topic("Aasii".to_string(), "Huh?".to_string(), &qos, TopicKind::WithKey)
       .expect("Failed to create topic");
 
     let data_writer: DataWriter<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>> =
@@ -960,7 +960,7 @@ mod tests {
       b: "Fobar".to_string(),
     };
 
-    let key = &data.get_key().into_hash_key();
+    let key = &data.get_key().hash_key();
     info!("key: {:?}", key);
 
     data_writer
@@ -983,7 +983,7 @@ mod tests {
       .create_publisher(&qos)
       .expect("Failed to create publisher");
     let topic = domain_participant
-      .create_topic("Aasii", "Huh?", &qos, TopicKind::WithKey)
+      .create_topic("Aasii".to_string(), "Huh?".to_string(), &qos, TopicKind::WithKey)
       .expect("Failed to create topic");
 
     let data_writer: DataWriter<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>> =
@@ -1001,6 +1001,7 @@ mod tests {
     let res = data_writer
       .wait_for_acknowledgments(Duration::from_secs(2))
       .unwrap();
-    assert_eq!(res, true); // we should get "true" immediately, because we have no Reliable QoS 
+    assert!(res) // we should get "true" immediately, because we have
+                           // no Reliable QoS
   }
 }
