@@ -4,6 +4,8 @@ use serde::{Serialize, Deserialize, de};
 
 use chrono::Utc;
 
+use cdr_encoding_size::*;
+
 use crate::{
   dds::{
     qos::policy::{
@@ -124,15 +126,15 @@ pub struct SubscriptionBuiltinTopicData {
 impl SubscriptionBuiltinTopicData {
   pub fn new(
     key: GUID,
-    topic_name: &str,
-    type_name: &str,
+    topic_name: String,
+    type_name: String,
     qos: &QosPolicies,
   ) -> SubscriptionBuiltinTopicData {
     let mut sbtd = SubscriptionBuiltinTopicData {
       key,
       participant_key: None,
-      topic_name: topic_name.to_string(),
-      type_name: type_name.to_string(),
+      topic_name,
+      type_name,
       durability: None,
       deadline: None,
       latency_budget: None,
@@ -277,9 +279,9 @@ impl Serialize for SubscriptionBuiltinTopicData {
 // ------------------------------------------
 
 #[derive(Debug, Clone, PartialEq, Eq, Hash)]
-pub struct SubscriptionBuiltinTopicData_Key(pub GUID);
+pub struct SubscriptionBuiltinTopicDataKey(pub GUID);
 
-impl Serialize for SubscriptionBuiltinTopicData_Key {
+impl Serialize for SubscriptionBuiltinTopicDataKey {
   fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
   where
     S: serde::Serializer,
@@ -310,8 +312,8 @@ impl DiscoveredReaderData {
     let reader_proxy = ReaderProxy::new(reader.get_guid());
     let mut subscription_topic_data = SubscriptionBuiltinTopicData::new(
       reader.get_guid(),
-      &topic.get_name(),
-      &topic.get_type().name().to_string(),
+      topic.get_name(),
+      topic.get_type().name().to_string(),
       &topic.get_qos(),
     );
     subscription_topic_data.set_participant_key(dp.get_guid());
@@ -323,7 +325,7 @@ impl DiscoveredReaderData {
     }
   }
 
-  pub fn default(topic_name: &str, type_name: &str) -> DiscoveredReaderData {
+  pub fn default(topic_name: String, type_name: String) -> DiscoveredReaderData {
     let rguid = GUID::dummy_test_guid(EntityKind::READER_WITH_KEY_BUILT_IN);
     let reader_proxy = ReaderProxy::new(rguid);
     let subscription_topic_data = SubscriptionBuiltinTopicData::new(
@@ -348,15 +350,15 @@ impl DiscoveredReaderData {
 }
 
 // separate type is needed to serialize correctly
-#[derive(Eq, PartialEq, Ord, PartialOrd, Debug, Clone, Copy, Hash)]
-pub struct DiscoveredReaderData_Key(pub GUID);
+#[derive(Eq, PartialEq, Ord, PartialOrd, Debug, Clone, Copy, Hash, CdrEncodingSize,)]
+pub struct DiscoveredReaderDataKey(pub GUID);
 
-impl Key for DiscoveredReaderData_Key {}
+impl Key for DiscoveredReaderDataKey {}
 
 impl Keyed for DiscoveredReaderData {
-  type K = DiscoveredReaderData_Key;
+  type K = DiscoveredReaderDataKey;
   fn get_key(&self) -> Self::K {
-    DiscoveredReaderData_Key(self.subscription_topic_data.key)
+    DiscoveredReaderDataKey(self.subscription_topic_data.key)
   }
 }
 
@@ -385,7 +387,7 @@ impl Serialize for DiscoveredReaderData {
 
 // -------
 
-impl<'de> Deserialize<'de> for DiscoveredReaderData_Key {
+impl<'de> Deserialize<'de> for DiscoveredReaderDataKey {
   fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
   where
     D: serde::Deserializer<'de>,
@@ -398,7 +400,7 @@ impl<'de> Deserialize<'de> for DiscoveredReaderData_Key {
   }
 }
 
-impl Serialize for DiscoveredReaderData_Key {
+impl Serialize for DiscoveredReaderDataKey {
   fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
   where
     S: serde::Serializer,
@@ -486,14 +488,14 @@ impl PublicationBuiltinTopicData {
   pub fn new(
     guid: GUID,
     participant_guid: GUID,
-    topic_name: &str,
-    type_name: &str,
+    topic_name: String,
+    type_name: String,
   ) -> PublicationBuiltinTopicData {
     PublicationBuiltinTopicData {
       key: guid,
       participant_key: Some(participant_guid),
-      topic_name: topic_name.to_string(),
-      type_name: type_name.to_string(),
+      topic_name,
+      type_name,
       durability: None,
       deadline: None,
       latency_budget: None,
@@ -563,10 +565,10 @@ impl Serialize for PublicationBuiltinTopicData {
 
 // ------------------------------------------
 
-#[derive(Debug, Clone, PartialEq, Eq, Hash)]
-pub struct PublicationBuiltinTopicData_Key(pub GUID);
+#[derive(Debug, Clone, PartialEq, Eq, Hash, CdrEncodingSize,)]
+pub struct PublicationBuiltinTopicDataKey(pub GUID);
 
-impl Serialize for PublicationBuiltinTopicData_Key {
+impl Serialize for PublicationBuiltinTopicDataKey {
   fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
   where
     S: serde::Serializer,
@@ -590,16 +592,16 @@ pub struct DiscoveredWriterData {
 }
 
 // separate type is needed to serialize correctly
-#[derive(Eq, PartialEq, Ord, PartialOrd, Debug, Clone, Copy, Hash)]
-pub struct DiscoveredWriterData_Key(pub GUID); // wrapper to enable custom PL CDR (de)serialization
+#[derive(Eq, PartialEq, Ord, PartialOrd, Debug, Clone, Copy, Hash, CdrEncodingSize,)]
+pub struct DiscoveredWriterDataKey(pub GUID); // wrapper to enable custom PL CDR (de)serialization
 
-impl Key for DiscoveredWriterData_Key {}
+impl Key for DiscoveredWriterDataKey {}
 
 impl Keyed for DiscoveredWriterData {
-  type K = DiscoveredWriterData_Key;
+  type K = DiscoveredWriterDataKey;
 
   fn get_key(&self) -> Self::K {
-    DiscoveredWriterData_Key(self.publication_topic_data.key)
+    DiscoveredWriterDataKey(self.publication_topic_data.key)
   }
 }
 
@@ -616,8 +618,8 @@ impl DiscoveredWriterData {
     let mut publication_topic_data = PublicationBuiltinTopicData::new(
       writer.get_guid(),
       dp.get_guid(),
-      &topic.get_name(),
-      &topic.get_type().name().to_string(),
+      topic.get_name(),
+      topic.get_type().name().to_string(),
     );
 
     publication_topic_data.read_qos(&topic.get_qos());
@@ -659,7 +661,7 @@ impl Serialize for DiscoveredWriterData {
   }
 }
 
-impl<'de> Deserialize<'de> for DiscoveredWriterData_Key {
+impl<'de> Deserialize<'de> for DiscoveredWriterDataKey {
   fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
   where
     D: serde::Deserializer<'de>,
@@ -672,7 +674,7 @@ impl<'de> Deserialize<'de> for DiscoveredWriterData_Key {
   }
 }
 
-impl Serialize for DiscoveredWriterData_Key {
+impl Serialize for DiscoveredWriterDataKey {
   fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
   where
     S: serde::Serializer,
@@ -783,9 +785,7 @@ impl<'de> Deserialize<'de> for DiscoveredTopicData {
   {
     let custom_ds = BuiltinDataDeserializer::new();
     let res = deserializer.deserialize_any(custom_ds)?;
-    let topic_data = res
-      .generate_topic_data()
-      .map_err(de::Error::custom)?;
+    let topic_data = res.generate_topic_data().map_err(de::Error::custom)?;
 
     Ok(DiscoveredTopicData::new(topic_data))
   }
@@ -801,7 +801,7 @@ impl Serialize for DiscoveredTopicData {
   }
 }
 
-pub type DiscoveredTopicData_Key = GUID;
+pub type DiscoveredTopicDataKey = GUID;
 
 impl Keyed for DiscoveredTopicData {
   type K = GUID;
@@ -820,7 +820,7 @@ impl Keyed for DiscoveredTopicData {
 // =======================================================================
 // =======================================================================
 
-#[derive(Copy, Clone, Debug, PartialOrd, PartialEq, Ord, Eq, Hash, Serialize, Deserialize)]
+#[derive(Copy, Clone, Debug, PartialOrd, PartialEq, Ord, Eq, Hash, Serialize, Deserialize,CdrEncodingSize,)]
 pub struct ParticipantMessageDataKind {
   value: [u8; 4],
 }
@@ -854,14 +854,18 @@ pub struct ParticipantMessageData {
 }
 
 impl Keyed for ParticipantMessageData {
-  type K = (GuidPrefix, ParticipantMessageDataKind);
+  type K = ParticipantMessageDataKey;
 
   fn get_key(&self) -> Self::K {
-    (self.guid, self.kind)
+    ParticipantMessageDataKey(self.guid, self.kind)
   }
 }
 
-impl Key for (GuidPrefix, ParticipantMessageDataKind) {}
+#[derive(Debug, PartialEq, Eq, Clone, Copy, Hash , Ord, PartialOrd, Serialize, Deserialize, CdrEncodingSize,)]
+pub struct ParticipantMessageDataKey(GuidPrefix, ParticipantMessageDataKind);
+
+
+impl Key for ParticipantMessageDataKey {}
 
 // =======================================================================
 // =======================================================================
@@ -944,7 +948,7 @@ mod tests {
   fn td_discovered_reader_data_ser_deser() {
     let mut reader_proxy = reader_proxy_data().unwrap();
     let sub_topic_data = subscription_builtin_topic_data().unwrap();
-    reader_proxy.remote_reader_guid = sub_topic_data.key.clone();
+    reader_proxy.remote_reader_guid = sub_topic_data.key;
     let content_filter = content_filter_data().unwrap();
 
     let drd = DiscoveredReaderData {
@@ -989,7 +993,7 @@ mod tests {
   fn td_discovered_writer_data_ser_deser() {
     let mut writer_proxy = writer_proxy_data().unwrap();
     let pub_topic_data = publication_builtin_topic_data().unwrap();
-    writer_proxy.remote_writer_guid = pub_topic_data.key.clone();
+    writer_proxy.remote_writer_guid = pub_topic_data.key;
 
     let dwd = DiscoveredWriterData {
       last_updated: Instant::now(),
