@@ -4,27 +4,27 @@ use std::{
 };
 
 #[allow(unused_imports)]
-use log::{error,warn,debug,trace,info};
+use log::{error, warn, debug, trace, info};
 
-use crate::{
-  dds::qos::HasQoSPolicy, 
-  structure::guid::GuidPrefix,
+use crate::{dds::qos::HasQoSPolicy, structure::guid::GuidPrefix};
+
+use crate::structure::{
+  guid::GUID, guid::EntityId, duration::Duration, entity::RTPSEntity, locator::LocatorList,
 };
 
-use crate::structure::{guid::GUID, guid::EntityId,
-  duration::Duration, entity::RTPSEntity, locator::LocatorList};
-
 use crate::{
   dds::{
-    rtps_reader_proxy::RtpsReaderProxy, reader::{ReaderIngredients,}, 
+    rtps_reader_proxy::RtpsReaderProxy,
+    reader::{ReaderIngredients},
     participant::DomainParticipant,
-    topic::Topic, traits::TopicDescription,
+    topic::Topic,
+    traits::TopicDescription,
   },
 };
 
 use super::{
   data_types::{
-    spdp_participant_data::SPDPDiscoveredParticipantData,
+    spdp_participant_data::SpdpDiscoveredParticipantData,
     topic_data::{
       DiscoveredReaderData, DiscoveredTopicData, DiscoveredWriterData, ParticipantMessageData,
       ReaderProxy, SubscriptionBuiltinTopicData, TopicBuiltinTopicData,
@@ -34,15 +34,14 @@ use super::{
 
 // If remote participant does not specifiy lease duration, how long silence
 // until we pronounce it dead.
-const DEFAULT_PARTICIPANT_LEASE_DURATION : Duration = Duration::from_secs(60);
+const DEFAULT_PARTICIPANT_LEASE_DURATION: Duration = Duration::from_secs(60);
 
 // How much longer to wait than lease duration before pronouncing lost.
-const PARTICIPANT_LEASE_DURATION_TOLREANCE : Duration = Duration::from_secs(0);
-
+const PARTICIPANT_LEASE_DURATION_TOLREANCE: Duration = Duration::from_secs(0);
 
 pub(crate) struct DiscoveryDB {
   my_guid: GUID,
-  participant_proxies: BTreeMap<GuidPrefix, SPDPDiscoveredParticipantData>,
+  participant_proxies: BTreeMap<GuidPrefix, SpdpDiscoveredParticipantData>,
   participant_last_life_signs: HashMap<GuidPrefix, Instant>,
   // local writer proxies for topics (topic name acts as key)
   local_topic_writers: HashMap<GUID, DiscoveredWriterData>,
@@ -50,8 +49,8 @@ pub(crate) struct DiscoveryDB {
   local_topic_readers: HashMap<GUID, DiscoveredReaderData>,
 
   // remote readers and writers (via discovery)
-  external_topic_readers: BTreeMap<GUID,DiscoveredReaderData>,
-  external_topic_writers: BTreeMap<GUID,DiscoveredWriterData>,
+  external_topic_readers: BTreeMap<GUID, DiscoveredReaderData>,
+  external_topic_writers: BTreeMap<GUID, DiscoveredWriterData>,
 
   topics: HashMap<String, DiscoveredTopicData>,
 
@@ -60,7 +59,7 @@ pub(crate) struct DiscoveryDB {
 }
 
 impl DiscoveryDB {
-  pub fn new(my_guid:GUID) -> DiscoveryDB {
+  pub fn new(my_guid: GUID) -> DiscoveryDB {
     DiscoveryDB {
       my_guid,
       participant_proxies: BTreeMap::new(),
@@ -76,46 +75,55 @@ impl DiscoveryDB {
   }
 
   // Returns if particiapnt was previously unkonwn
-  pub fn update_participant(&mut self, data: &SPDPDiscoveredParticipantData) -> bool {
-      debug!("update_participant: {:?}",&data);
-      let guid = data.participant_guid;
+  pub fn update_participant(&mut self, data: &SpdpDiscoveredParticipantData) -> bool {
+    debug!("update_participant: {:?}", &data);
+    let guid = data.participant_guid;
 
-      // sanity check
-      if guid.entityId != EntityId::ENTITYID_PARTICIPANT {
-        error!("Discovered participant GUID entity_id is not for participant: {:?}",guid);
-        // Maybe we should discard the participant here?
-        return false 
+    // sanity check
+    if guid.entity_id != EntityId::ENTITYID_PARTICIPANT {
+      error!(
+        "Discovered participant GUID entity_id is not for participant: {:?}",
+        guid
+      );
+      // Maybe we should discard the participant here?
+      return false;
+    }
+
+    // We allow discovery to discover self, since our discovery readers
+    // will receive our own announcements via broadcast. If we do not recognize
+    // our own participant, there is confusion about unknown writers on the
+    // discovery topics.
+    //
+    // if guid == self.my_guid {
+    //   debug!("DiscoveryDB discovered self. Skipping.");
+    //   return
+    // }
+
+    let mut new_participant = false;
+    if self.participant_proxies.get(&guid.guid_prefix).is_none() {
+      info!("New remote participant: {:?}", &data);
+      new_participant = true;
+      if guid == self.my_guid {
+        info!(
+          "Remote participant {:?} is myself, but some reflection is good.",
+          guid
+        );
+        new_participant = false;
       }
+    }
+    // actual work here:
+    self
+      .participant_proxies
+      .insert(guid.guid_prefix, data.clone());
+    self
+      .participant_last_life_signs
+      .insert(guid.guid_prefix, Instant::now());
 
-      // We allow discovery to discover self, since our discovery readers
-      // will receive our own announcements via broadcast. If we do not recognize
-      // our own participant, there is confusion about unknown writers on the
-      // discovery topics.
-      //
-      // if guid == self.my_guid {
-      //   debug!("DiscoveryDB discovered self. Skipping.");
-      //   return
-      // }
-
-      let mut new_participant = false;
-      if self.participant_proxies.get( &guid.guidPrefix ).is_none() {
-        info!("New remote participant: {:?}", &data);
-        new_participant = true;
-        if guid == self.my_guid {
-          info!("Remote participant {:?} is myself, but some reflection is good.",
-            guid);
-          new_participant = false;
-        }
-      }
-      // actual work here:
-      self.participant_proxies.insert(guid.guidPrefix, data.clone());
-      self.participant_last_life_signs.insert(guid.guidPrefix, Instant::now() );
-
-      new_participant
+    new_participant
   }
 
   pub fn remove_participant(&mut self, guid_prefix: GuidPrefix) {
-    info!("removing participant {:?}",guid_prefix);
+    info!("removing participant {:?}", guid_prefix);
     self.participant_proxies.remove(&guid_prefix);
     self.participant_last_life_signs.remove(&guid_prefix);
 
@@ -124,40 +132,41 @@ impl DiscoveryDB {
     self.remove_topic_writer_with_prefix(guid_prefix);
   }
 
-  pub fn find_participant_proxy(&self, guid_prefix: GuidPrefix) 
-    -> Option<&SPDPDiscoveredParticipantData> 
-  {
-    self.participant_proxies.get( &guid_prefix )
+  pub fn find_participant_proxy(
+    &self,
+    guid_prefix: GuidPrefix,
+  ) -> Option<&SpdpDiscoveredParticipantData> {
+    self.participant_proxies.get(&guid_prefix)
   }
 
-  pub fn find_remote_reader(&self, guid:GUID) -> Option<&DiscoveredReaderData>{
+  pub fn find_remote_reader(&self, guid: GUID) -> Option<&DiscoveredReaderData> {
     self.external_topic_readers.get(&guid)
   }
 
   fn remove_topic_reader_with_prefix(&mut self, guid_prefix: GuidPrefix) {
     // TODO: Implement this using .drain_filter() in BTreeMap once it lands in stable.
-    let to_remove :Vec<GUID> = 
-          self.external_topic_readers
-            .range( guid_prefix.range() )
-            .map(|(g,_)| *g )
-            .collect();
+    let to_remove: Vec<GUID> = self
+      .external_topic_readers
+      .range(guid_prefix.range())
+      .map(|(g, _)| *g)
+      .collect();
     for guid in to_remove {
       self.external_topic_readers.remove(&guid);
     }
   }
 
   pub fn remove_topic_reader(&mut self, guid: GUID) {
-    info!("remove_topic_reader {:?}",guid);
+    info!("remove_topic_reader {:?}", guid);
     self.external_topic_readers.remove(&guid);
   }
 
   fn remove_topic_writer_with_prefix(&mut self, guid_prefix: GuidPrefix) {
     // TODO: Implement this using .drain_filter() in BTreeMap once it lands in stable.
-    let to_remove :Vec<GUID> = 
-          self.external_topic_writers
-            .range( guid_prefix.range() )
-            .map(|(g,_)| *g )
-            .collect();
+    let to_remove: Vec<GUID> = self
+      .external_topic_writers
+      .range(guid_prefix.range())
+      .map(|(g, _)| *g)
+      .collect();
     for guid in to_remove {
       self.external_topic_writers.remove(&guid);
     }
@@ -167,7 +176,6 @@ impl DiscoveryDB {
     self.external_topic_writers.remove(&guid);
   }
 
-
   // Delete participant proxies, if we have not heard of them within lease_duration
   pub fn participant_cleanup(&mut self) -> Vec<GuidPrefix> {
     let inow = Instant::now();
@@ -175,9 +183,10 @@ impl DiscoveryDB {
     let mut to_remove = Vec::new();
     // TODO: We are not cleaning up liast_life_signs table, but that should not be a problem,
     // except for a slight memory leak.
-    for (&guid,sp) in self.participant_proxies.iter() {
-      let lease_duration = sp.lease_duration
-            .unwrap_or( DEFAULT_PARTICIPANT_LEASE_DURATION );
+    for (&guid, sp) in self.participant_proxies.iter() {
+      let lease_duration = sp
+        .lease_duration
+        .unwrap_or(DEFAULT_PARTICIPANT_LEASE_DURATION);
       //let lease_duration = lease_duration + lease_duration; // double it
       match self.participant_last_life_signs.get(&guid) {
         Some(&last_life) => {
@@ -188,7 +197,7 @@ impl DiscoveryDB {
           } else {
             info!("participant cleanup - deleting participant proxy {:?}. lease_duration = {:?} elapsed = {:?}",
                   guid, lease_duration, elapsed);
-            to_remove.push(guid);    
+            to_remove.push(guid);
           }
         }
         None => {
@@ -206,35 +215,35 @@ impl DiscoveryDB {
     // TODO: This entire function has silly implementation.
     // We should really have a separate map from Topic to Readers & Writers
     if self
-        .local_topic_readers
-        .iter()
-        .any(|(_, p)| p.subscription_topic_data.topic_name() == topic_name)
+      .local_topic_readers
+      .iter()
+      .any(|(_, p)| p.subscription_topic_data.topic_name() == topic_name)
     {
-      return true
+      return true;
     }
 
     if self
-        .local_topic_writers
-        .iter()
-        .any(|(_, p)| p.publication_topic_data.topic_name == topic_name)
+      .local_topic_writers
+      .iter()
+      .any(|(_, p)| p.publication_topic_data.topic_name == topic_name)
     {
-      return true
+      return true;
     }
 
     if self
-        .external_topic_readers
-        .values()
-        .any(|p| p.subscription_topic_data.topic_name() == topic_name)
+      .external_topic_readers
+      .values()
+      .any(|p| p.subscription_topic_data.topic_name() == topic_name)
     {
-      return true
+      return true;
     }
 
     if self
-        .external_topic_writers
-        .values()
-        .any(|p| p.publication_topic_data.topic_name == topic_name)
+      .external_topic_writers
+      .values()
+      .any(|p| p.publication_topic_data.topic_name == topic_name)
     {
-      return true
+      return true;
     }
 
     false
@@ -246,19 +255,22 @@ impl DiscoveryDB {
       .topics
       .iter()
       .map(|(tn, _)| tn)
-      .filter(|tn| !self.topic_has_writers_or_readers(tn)).cloned()
+      .filter(|tn| !self.topic_has_writers_or_readers(tn))
+      .cloned()
       .collect();
     for dt in dead_topics.iter() {
       self.topics.remove(dt);
     }
   }
 
-  pub fn get_participants(&self) -> impl Iterator<Item = &SPDPDiscoveredParticipantData> {
+  pub fn get_participants(&self) -> impl Iterator<Item = &SpdpDiscoveredParticipantData> {
     self.participant_proxies.values()
   }
 
   pub fn update_local_topic_writer(&mut self, writer: DiscoveredWriterData) {
-    self.local_topic_writers.insert(writer.writer_proxy.remote_writer_guid, writer);
+    self
+      .local_topic_writers
+      .insert(writer.writer_proxy.remote_writer_guid, writer);
     self.writers_updated = true;
   }
 
@@ -267,58 +279,84 @@ impl DiscoveryDB {
     self.writers_updated = true;
   }
 
-  pub fn get_external_reader_proxies<'a>(&'a self) -> impl Iterator<Item = &DiscoveredReaderData> + 'a {
+  pub fn get_external_reader_proxies<'a>(
+    &'a self,
+  ) -> impl Iterator<Item = &DiscoveredReaderData> + 'a {
     self.external_topic_readers.values()
   }
 
-  pub fn get_external_writer_proxies<'a>(&'a self) -> impl Iterator<Item = &DiscoveredWriterData> + 'a {
+  pub fn get_external_writer_proxies<'a>(
+    &'a self,
+  ) -> impl Iterator<Item = &DiscoveredWriterData> + 'a {
     self.external_topic_writers.values()
   }
 
   // TODO: This is silly. Returns one of the paramters cloned, or None
   // TODO: Why are we here checking if discovery db already has this? What about reader proxies in writers?
-  pub fn update_subscription(&mut self, data: &DiscoveredReaderData) -> Option<(DiscoveredReaderData, RtpsReaderProxy)> {
+  pub fn update_subscription(
+    &mut self,
+    data: &DiscoveredReaderData,
+  ) -> Option<(DiscoveredReaderData, RtpsReaderProxy)> {
     let guid = data.reader_proxy.remote_reader_guid;
     // we could return None to indicate that we already knew all about this reader
     // To do that, we should check that the reader is the same as what we have in the DB already.
     match self.external_topic_readers.get(&guid) {
-      Some(drd) if drd == data  => None, // already have this
+      Some(drd) if drd == data => None, // already have this
       _ => {
-        self.external_topic_readers.insert( guid, data.clone() );
+        self.external_topic_readers.insert(guid, data.clone());
         // fill in the default locators, in case DRD did not provide any
-        let default_locator_lists = 
-          self.find_participant_proxy(guid.guidPrefix)
-            .map(|pp| {
-              debug!("Added default locators to Reader {:?}", guid);
-              ( pp.default_unicast_locators.clone(), 
-                pp.default_multicast_locators.clone() ) } )
-            .unwrap_or_else( || {
-                if guid.guidPrefix != GuidPrefix::GUIDPREFIX_UNKNOWN {
-                  // This is normal, since we might not know about the participant yet.
-                  debug!("No remote participant known for {:?}\nSearched with {:?} in {:?}"
-                    ,data, guid.guidPrefix, self.participant_proxies.keys() );
-                }
-                (LocatorList::new(), LocatorList::new()) 
-              } );
-        debug!("External reader: {:?}",data);
-        Some( ( data.clone(), 
-                RtpsReaderProxy::from_discovered_reader_data(data, 
-                  default_locator_lists.0 , default_locator_lists.1 )))
+        let default_locator_lists = self
+          .find_participant_proxy(guid.guid_prefix)
+          .map(|pp| {
+            debug!("Added default locators to Reader {:?}", guid);
+            (
+              pp.default_unicast_locators.clone(),
+              pp.default_multicast_locators.clone(),
+            )
+          })
+          .unwrap_or_else(|| {
+            if guid.guid_prefix != GuidPrefix::GUIDPREFIX_UNKNOWN {
+              // This is normal, since we might not know about the participant yet.
+              debug!(
+                "No remote participant known for {:?}\nSearched with {:?} in {:?}",
+                data,
+                guid.guid_prefix,
+                self.participant_proxies.keys()
+              );
+            }
+            (LocatorList::new(), LocatorList::new())
+          });
+        debug!("External reader: {:?}", data);
+        Some((
+          data.clone(),
+          RtpsReaderProxy::from_discovered_reader_data(
+            data,
+            default_locator_lists.0,
+            default_locator_lists.1,
+          ),
+        ))
       }
     }
   }
 
   // TODO: This is silly. Returns one of the paramters cloned, or None
-  pub fn update_publication(&mut self, data: &DiscoveredWriterData) -> Option<DiscoveredWriterData> {
-    match self.external_topic_writers.get(&data.writer_proxy.remote_writer_guid) {
-      Some(dwd) if dwd == data => None , // already up to date
+  pub fn update_publication(
+    &mut self,
+    data: &DiscoveredWriterData,
+  ) -> Option<DiscoveredWriterData> {
+    match self
+      .external_topic_writers
+      .get(&data.writer_proxy.remote_writer_guid)
+    {
+      Some(dwd) if dwd == data => None, // already up to date
       _ => {
-        self.external_topic_writers.insert(data.writer_proxy.remote_writer_guid, data.clone());
-        debug!("External writer: {:?}",data);
-        Some(data.clone() )
+        self
+          .external_topic_writers
+          .insert(data.writer_proxy.remote_writer_guid, data.clone());
+        debug!("External writer: {:?}", data);
+        Some(data.clone())
       }
     }
-    
   }
 
   pub fn update_topic_data_drd(&mut self, drd: &DiscoveredReaderData) {
@@ -385,7 +423,7 @@ impl DiscoveryDB {
   }
 
   pub fn update_topic_data(&mut self, data: &DiscoveredTopicData) -> bool {
-    trace!("Update topic data: {:?}",&data);
+    trace!("Update topic data: {:?}", &data);
     let topic_name = data.topic_data.name.clone();
 
     match self.topics.get_mut(&data.topic_data.name) {
@@ -398,7 +436,6 @@ impl DiscoveryDB {
     true
   }
 
-  
   // local topic readers
   pub fn update_local_topic_reader(
     &mut self,
@@ -416,8 +453,8 @@ impl DiscoveryDB {
 
     let mut subscription_data = SubscriptionBuiltinTopicData::new(
       reader_guid,
-      &topic.get_name(),
-      topic.get_type().name(),
+      topic.get_name(),
+      topic.get_type().name().to_string(),
       &topic.get_qos(),
     );
     subscription_data.set_participant_key(domain_participant.get_guid());
@@ -459,20 +496,18 @@ impl DiscoveryDB {
     self.writers_updated = updated;
   }
 
-  pub fn get_all_local_topic_readers(
-    &self,
-  ) -> impl Iterator<Item = &DiscoveredReaderData> {
+  pub fn get_all_local_topic_readers(&self) -> impl Iterator<Item = &DiscoveredReaderData> {
     self.local_topic_readers.iter().map(|(_, p)| p)
   }
 
-  pub fn get_all_local_topic_writers(
-    &self,
-  ) -> impl Iterator<Item = &DiscoveredWriterData> {
+  pub fn get_all_local_topic_writers(&self) -> impl Iterator<Item = &DiscoveredWriterData> {
     self.local_topic_writers.iter().map(|(_, p)| p)
   }
 
   pub fn get_all_topics(&self) -> impl Iterator<Item = &DiscoveredTopicData> {
-    self.topics.iter()
+    self
+      .topics
+      .iter()
       .filter(|(s, _)| !s.starts_with("DCPS"))
       .map(|(_, v)| v)
   }
@@ -483,13 +518,11 @@ impl DiscoveryDB {
     &'a self,
     topic: &'a T,
   ) -> Vec<&DiscoveredReaderData> {
-    let topic_name = String::from(topic.get_name());
+    let topic_name = topic.get_name();
     self
       .local_topic_readers
       .iter()
-      .filter(|(_, p)| {
-        *p.subscription_topic_data.topic_name() == topic_name
-      })
+      .filter(|(_, p)| *p.subscription_topic_data.topic_name() == topic_name)
       .map(|(_, p)| p)
       .collect()
   }
@@ -499,8 +532,8 @@ impl DiscoveryDB {
     let prefix = data.guid;
     self
       .external_topic_writers
-      .range_mut( prefix.range() )
-      .for_each(|(_guid,p)| p.last_updated = now);
+      .range_mut(prefix.range())
+      .for_each(|(_guid, p)| p.last_updated = now);
   }
 }
 
@@ -544,7 +577,7 @@ mod tests {
 
     std::thread::sleep(StdDuration::from_secs(2));
     discoverydb.participant_cleanup();
-    assert!(discoverydb.participant_proxies.len() == 0);
+    assert!(discoverydb.participant_proxies.is_empty());
 
     // TODO: more operations tests
   }
@@ -554,7 +587,7 @@ mod tests {
     let _discoverydb = DiscoveryDB::new(GUID::new_particiapnt_guid());
     let topic_name = String::from("some_topic");
     let type_name = String::from("RandomData");
-    let _dreader = DiscoveredReaderData::default(&topic_name, &type_name);
+    let _dreader = DiscoveredReaderData::default(topic_name, type_name);
 
     // TODO: more tests :)
   }
@@ -566,16 +599,16 @@ mod tests {
     let domain_participant = DomainParticipant::new(0).expect("Failed to create publisher");
     let topic = domain_participant
       .create_topic(
-        "Foobar",
-        "RandomData",
+        "Foobar".to_string(),
+        "RandomData".to_string(),
         &QosPolicies::qos_none(),
         TopicKind::WithKey,
       )
       .unwrap();
     let topic2 = domain_participant
       .create_topic(
-        "Barfoo",
-        "RandomData",
+        "Barfoo".to_string(),
+        "RandomData".to_string(),
         &QosPolicies::qos_none(),
         TopicKind::WithKey,
       )
@@ -586,13 +619,14 @@ mod tests {
       .unwrap();
     let dw = publisher1
       .create_datawriter::<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>>(
-        topic.clone(), None,
+        topic.clone(),
+        None,
       )
       .unwrap();
 
     let writer_data = DiscoveredWriterData::new(&dw, &topic, &domain_participant);
 
-    let _writer_key = writer_data.writer_proxy.remote_writer_guid.clone();
+    let _writer_key = writer_data.writer_proxy.remote_writer_guid;
     discovery_db.update_local_topic_writer(writer_data);
     assert_eq!(discovery_db.local_topic_writers.len(), 1);
 
@@ -601,14 +635,12 @@ mod tests {
       .unwrap();
     let dw2 = publisher2
       .create_datawriter::<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>>(
-       topic.clone(), None,
+        topic.clone(),
+        None,
       )
       .unwrap();
     let writer_data2 = DiscoveredWriterData::new(&dw2, &topic, &domain_participant);
-    let _writer2_key = writer_data2
-      .writer_proxy
-      .remote_writer_guid
-      .clone();
+    let _writer2_key = writer_data2.writer_proxy.remote_writer_guid;
     discovery_db.update_local_topic_writer(writer_data2);
     assert_eq!(discovery_db.local_topic_writers.len(), 2);
 
@@ -635,7 +667,7 @@ mod tests {
     };
     discovery_db.update_subscription(&dreader2);
 
-    let reader3 = reader1.clone();
+    let reader3 = reader1;
     let reader3sub = reader1sub.clone();
     let dreader3 = DiscoveredReaderData {
       reader_proxy: reader3,
@@ -652,8 +684,8 @@ mod tests {
     let dp = DomainParticipant::new(0).expect("Failed to create participant");
     let topic = dp
       .create_topic(
-        "some topic name",
-        "Wazzup",
+        "some topic name".to_string(),
+        "Wazzup".to_string(),
         &QosPolicies::qos_none(),
         TopicKind::WithKey,
       )
@@ -661,7 +693,8 @@ mod tests {
     let mut discoverydb = DiscoveryDB::new(GUID::new_particiapnt_guid());
 
     let (notification_sender, _notification_receiver) = mio_extras::channel::sync_channel(100);
-    let (status_sender, _status_reciever) = mio_extras::channel::sync_channel::<DataReaderStatus>(100);
+    let (status_sender, _status_reciever) =
+      mio_extras::channel::sync_channel::<DataReaderStatus>(100);
     let (_reader_commander1, reader_command_receiver1) =
       mio_extras::channel::sync_channel::<ReaderCommand>(100);
     let (_reader_commander2, reader_command_receiver2) =
@@ -671,7 +704,7 @@ mod tests {
       guid: GUID::dummy_test_guid(EntityKind::READER_NO_KEY_USER_DEFINED),
       notification_sender: notification_sender.clone(),
       status_sender: status_sender.clone(),
-      topic_name: topic.get_name().to_string(),
+      topic_name: topic.get_name(),
       qos_policy: QosPolicies::qos_none(),
       data_reader_command_receiver: reader_command_receiver1,
     };
@@ -688,13 +721,17 @@ mod tests {
       reader_ing,
       Arc::new(RwLock::new(DDSCache::new())),
       Rc::new(UDPSender::new(0).unwrap()),
+      mio_extras::timer::Builder::default().build(),
     );
 
     let reader_ing = ReaderIngredients {
-      guid: GUID::new_with_prefix_and_id(GuidPrefix::new(b"Another fake"), EntityId {
-        entityKey: [1, 2, 3],
-        entityKind: EntityKind::READER_NO_KEY_USER_DEFINED
-      }), // GUID needs to be different in order to be added
+      guid: GUID::new_with_prefix_and_id(
+        GuidPrefix::new(b"Another fake"),
+        EntityId {
+          entity_key: [1, 2, 3],
+          entity_kind: EntityKind::READER_NO_KEY_USER_DEFINED,
+        },
+      ), // GUID needs to be different in order to be added
       notification_sender: notification_sender.clone(),
       status_sender: status_sender.clone(),
       topic_name: topic.get_name().to_string(),
@@ -710,6 +747,7 @@ mod tests {
       reader_ing,
       Arc::new(RwLock::new(DDSCache::new())),
       Rc::new(UDPSender::new(0).unwrap()),
+      mio_extras::timer::Builder::default().build(),
     );
   }
 }
