@@ -15,18 +15,17 @@
 //!
 
 #![warn(clippy::all)]
-#![allow(clippy::option_map_unit_fn, clippy::wrong_self_convention, clippy::single_match, )]
-
-#![allow(dead_code)]
-#![allow(non_camel_case_types)]
-#![allow(non_snake_case)]
-#![allow(non_upper_case_globals)]
+#![allow(
+  clippy::option_map_unit_fn,
+  clippy::wrong_self_convention,
+  clippy::single_match,
+  dead_code
+)]
 
 #[macro_use]
 mod serialization_test;
 #[macro_use]
 mod checked_impl;
-mod common;
 mod discovery;
 mod messages;
 mod network;
