@@ -1,8 +1,7 @@
-
 use crate::messages::submessages::submessage_elements::parameter_list::ParameterList;
 use crate::messages::submessages::submessage_elements::serialized_payload::SerializedPayload;
 use crate::structure::guid::EntityId;
-use crate::structure::sequence_number::{SequenceNumber,FragmentNumber};
+use crate::structure::sequence_number::{SequenceNumber, FragmentNumber};
 
 use crate::messages::submessages::submessages::*;
 
@@ -18,6 +17,7 @@ use std::io;
 /// The fragments contained in the DataFrag Submessages are then re-assembled by
 /// the RTPS Reader.
 #[derive(Debug, PartialEq, Clone)]
+#[cfg_attr(test, derive(Default))]
 pub struct DataFrag {
   /// Identifies the RTPS Reader entity that is being informed of the change
   /// to the data-object.
@@ -70,14 +70,15 @@ impl<'a> DataFrag {
       u16::read_from_stream_unbuffered_with_ctx(endianness, &mut cursor).map_err(map_speedy_err)?;
     let octets_to_inline_qos =
       u16::read_from_stream_unbuffered_with_ctx(endianness, &mut cursor).map_err(map_speedy_err)?;
-    let reader_id =
-      EntityId::read_from_stream_unbuffered_with_ctx(endianness, &mut cursor).map_err(map_speedy_err)?;
-    let writer_id =
-      EntityId::read_from_stream_unbuffered_with_ctx(endianness, &mut cursor).map_err(map_speedy_err)?;
-    let writer_sn =
-      SequenceNumber::read_from_stream_unbuffered_with_ctx(endianness, &mut cursor).map_err(map_speedy_err)?;
+    let reader_id = EntityId::read_from_stream_unbuffered_with_ctx(endianness, &mut cursor)
+      .map_err(map_speedy_err)?;
+    let writer_id = EntityId::read_from_stream_unbuffered_with_ctx(endianness, &mut cursor)
+      .map_err(map_speedy_err)?;
+    let writer_sn = SequenceNumber::read_from_stream_unbuffered_with_ctx(endianness, &mut cursor)
+      .map_err(map_speedy_err)?;
     let fragment_starting_num =
-      FragmentNumber::read_from_stream_unbuffered_with_ctx(endianness, &mut cursor).map_err(map_speedy_err)?;
+      FragmentNumber::read_from_stream_unbuffered_with_ctx(endianness, &mut cursor)
+        .map_err(map_speedy_err)?;
     let fragments_in_submessage =
       u16::read_from_stream_unbuffered_with_ctx(endianness, &mut cursor).map_err(map_speedy_err)?;
     let fragment_size =
@@ -109,7 +110,7 @@ impl<'a> DataFrag {
     };
 
     // Payload should be always present, be it data or key fragments.
-    let serialized_payload = 
+    let serialized_payload =
       SerializedPayload::from_bytes(buffer.clone().split_off(cursor.position() as usize))?;
 
     Ok(DataFrag {
@@ -126,30 +127,15 @@ impl<'a> DataFrag {
   }
 }
 
-#[cfg(test)]
-impl Default for DataFrag {
-  fn default() -> Self {
-    DataFrag {
-      reader_id: EntityId::default(),
-      writer_id: EntityId::default(),
-      writer_sn: SequenceNumber::default(),
-      fragment_starting_num: FragmentNumber::default(),
-      fragments_in_submessage: 0,
-      data_size: 0,
-      fragment_size: 0,
-      inline_qos: None,
-      serialized_payload: SerializedPayload::default(),
-    }
-  }
-}
-
 impl<C: Context> Writable<C> for DataFrag {
   fn write_to<T: ?Sized + Writer<C>>(&self, writer: &mut T) -> Result<(), C::Error> {
     writer.write_u16(0)?;
     if self.inline_qos.is_some() && !self.inline_qos.as_ref().unwrap().parameters.is_empty() {
       debug!("self.inline_qos {:?}", self.inline_qos);
       todo!()
-    } else if self.inline_qos.is_some() && self.inline_qos.as_ref().unwrap().parameters.is_empty() || self.inline_qos.is_none() {
+    } else if self.inline_qos.is_some() && self.inline_qos.as_ref().unwrap().parameters.is_empty()
+      || self.inline_qos.is_none()
+    {
       writer.write_u16(24)?;
     }
     writer.write_value(&self.reader_id)?;
