@@ -30,10 +30,10 @@ mod tests {
       InfoSource {
           protocol_version: ProtocolVersion::PROTOCOLVERSION_2_2,
           vendor_id: VendorId {
-              vendorId: [0xFF, 0xAA]
+              vendor_id: [0xFF, 0xAA]
           },
           guid_prefix: GuidPrefix {
-              entityKey: [0x01, 0x02, 0x6D, 0x3F,
+              entity_key: [0x01, 0x02, 0x6D, 0x3F,
                           0x7E, 0x07, 0x00, 0x00,
                           0x01, 0x00, 0x00, 0x00]
           }
