@@ -4,21 +4,20 @@ use crate::structure::parameter_id::ParameterId;
 
 #[derive(Debug, PartialEq, Eq, Serialize, Deserialize, Clone, Copy)]
 pub struct VendorId {
-  pub vendorId: [u8; 2],
+  pub vendor_id: [u8; 2],
 }
 
 impl VendorId {
   pub const VENDOR_UNKNOWN: VendorId = VendorId {
-    vendorId: [0x00; 2],
+    vendor_id: [0x00; 2],
   };
 
-  /// assigned by OMG DDS SIG on 2020-11-21 
+  /// assigned by OMG DDS SIG on 2020-11-21
   pub const ATOSTEK: VendorId = VendorId {
-    vendorId: [0x01, 0x12],  
+    vendor_id: [0x01, 0x12],
   };
 
   pub const THIS_IMPLEMENTATION: VendorId = VendorId::ATOSTEK;
-
 }
 
 impl Default for VendorId {
@@ -48,8 +47,8 @@ impl<'a, C: Context> Readable<'a, C> for VendorId {
   #[inline]
   fn read_from<R: Reader<'a, C>>(reader: &mut R) -> Result<Self, C::Error> {
     let mut vendor_id = VendorId::default();
-    for i in 0..vendor_id.vendorId.len() {
-      vendor_id.vendorId[i] = reader.read_u8()?;
+    for i in 0..vendor_id.vendor_id.len() {
+      vendor_id.vendor_id[i] = reader.read_u8()?;
     }
     Ok(vendor_id)
   }
@@ -63,7 +62,7 @@ impl<'a, C: Context> Readable<'a, C> for VendorId {
 impl<C: Context> Writable<C> for VendorId {
   #[inline]
   fn write_to<T: ?Sized + Writer<C>>(&self, writer: &mut T) -> Result<(), C::Error> {
-    for elem in &self.vendorId {
+    for elem in &self.vendor_id {
       writer.write_u8(*elem)?
     }
     Ok(())
