@@ -1,7 +1,7 @@
-// use crate::discovery::data_types::topic_data::PublicationBuiltinTopicData_Key;
-// use crate::discovery::data_types::topic_data::SubscriptionBuiltinTopicData_Key;
-use crate::discovery::data_types::topic_data::DiscoveredReaderData_Key;
-use crate::discovery::data_types::topic_data::DiscoveredWriterData_Key;
+// use crate::discovery::data_types::topic_data::PublicationBuiltinTopicDataKey;
+// use crate::discovery::data_types::topic_data::SubscriptionBuiltinTopicDataKey;
+use crate::discovery::data_types::topic_data::DiscoveredReaderDataKey;
+use crate::discovery::data_types::topic_data::DiscoveredWriterDataKey;
 use crate::{
   structure::{
     locator::{LocatorList, LocatorData},
@@ -20,8 +20,8 @@ use crate::{
         SubscriptionBuiltinTopicData, ReaderProxy, DiscoveredReaderData, WriterProxy,
         PublicationBuiltinTopicData, DiscoveredWriterData, TopicBuiltinTopicData,
       },
-      spdp_participant_data::SPDPDiscoveredParticipantData,
-      spdp_participant_data::SPDPDiscoveredParticipantData_Key,
+      spdp_participant_data::SpdpDiscoveredParticipantData,
+      spdp_participant_data::SpdpDiscoveredParticipantDataKey,
     },
   },
   messages::{
@@ -44,13 +44,13 @@ struct StringData {
 }
 
 impl StringData {
-  pub fn new(parameter_id: ParameterId, string_data: &str) -> StringData {
+  pub fn new(parameter_id: ParameterId, string_data: String) -> StringData {
     let parameter_length = string_data.len() as u16;
     let parameter_length = parameter_length + (4 - parameter_length % 4) + 4;
     StringData {
       parameter_id,
       parameter_length,
-      string_data: string_data.to_string(),
+      string_data,
     }
   }
 }
@@ -110,18 +110,22 @@ struct EntityName {
   entity_name: String,
 }
 
-
-pub struct BuiltinDataSerializer_Key {
+pub struct BuiltinDataSerializerKey {
   pub participant_guid: GUID,
 }
 
-impl BuiltinDataSerializer_Key {
-
-  pub fn from_data(participant_data: SPDPDiscoveredParticipantData_Key) -> BuiltinDataSerializer_Key {
-    BuiltinDataSerializer_Key { participant_guid: participant_data.0 }
+impl BuiltinDataSerializerKey {
+  pub fn from_data(participant_data: SpdpDiscoveredParticipantDataKey) -> BuiltinDataSerializerKey {
+    BuiltinDataSerializerKey {
+      participant_guid: participant_data.0,
+    }
   }
 
-  pub fn serialize<S: Serializer>(self, serializer: S, add_sentinel: bool) -> Result<S::Ok, S::Error> {
+  pub fn serialize<S: Serializer>(
+    self,
+    serializer: S,
+    add_sentinel: bool,
+  ) -> Result<S::Ok, S::Error> {
     let mut s = serializer
       .serialize_struct("SPDPParticipantData_Key", 1)
       .unwrap();
@@ -142,7 +146,6 @@ impl BuiltinDataSerializer_Key {
     )
     .unwrap();
   }
-
 }
 
 pub struct BuiltinDataSerializer<'a> {
@@ -324,7 +327,7 @@ impl<'a> BuiltinDataSerializer<'a> {
   }
 
   pub fn from_participant_data(
-    participant_data: &'a SPDPDiscoveredParticipantData,
+    participant_data: &'a SpdpDiscoveredParticipantData,
   ) -> BuiltinDataSerializer<'a> {
     BuiltinDataSerializer {
       protocol_version: Some(participant_data.protocol_version),
@@ -613,18 +616,17 @@ impl<'a> BuiltinDataSerializer<'a> {
   // -----------------------
 
   pub fn from_discovered_reader_data_key(
-    discovered_reader_data: &'a DiscoveredReaderData_Key,
+    discovered_reader_data: &'a DiscoveredReaderDataKey,
   ) -> BuiltinDataSerializer<'a> {
     BuiltinDataSerializer::from_endpoint_guid(&discovered_reader_data.0)
   }
 
   pub fn from_discovered_writer_data_key(
-    discovered_writer_data: &'a DiscoveredWriterData_Key,
+    discovered_writer_data: &'a DiscoveredWriterDataKey,
   ) -> BuiltinDataSerializer<'a> {
     BuiltinDataSerializer::from_endpoint_guid(&discovered_writer_data.0)
   }
 
-
   pub fn serialize<S: Serializer>(
     self,
     serializer: S,
@@ -697,7 +699,6 @@ impl<'a> BuiltinDataSerializer<'a> {
     s.end()
   }
 
-
   fn fields_amount(&self) -> usize {
     let mut count: usize = 0;
 
@@ -708,9 +709,9 @@ impl<'a> BuiltinDataSerializer<'a> {
     count += self.participant_guid.is_some() as usize;
     count += self.metatraffic_unicast_locators.unwrap_or(&empty_ll).len();
     count += self
-        .metatraffic_multicast_locators
-        .unwrap_or(&empty_ll)
-        .len();
+      .metatraffic_multicast_locators
+      .unwrap_or(&empty_ll)
+      .len();
     count += self.default_unicast_locators.unwrap_or(&empty_ll).len();
     count += self.default_multicast_locators.unwrap_or(&empty_ll).len();
     count += self.available_builtin_endpoints.is_some() as usize;
@@ -947,20 +948,20 @@ impl<'a> BuiltinDataSerializer<'a> {
   }
 
   fn add_topic_name<S: Serializer>(&self, s: &mut S::SerializeStruct) {
-    if let Some(name) = self.topic_name.as_ref() {
+    if let Some(name) = self.topic_name {
       s.serialize_field(
         "topic_name",
-        &StringData::new(ParameterId::PID_TOPIC_NAME, name),
+        &StringData::new(ParameterId::PID_TOPIC_NAME, name.to_string()),
       )
       .unwrap();
     }
   }
 
   fn add_type_name<S: Serializer>(&self, s: &mut S::SerializeStruct) {
-    if let Some(name) = self.type_name.as_ref() {
+    if let Some(name) = self.type_name {
       s.serialize_field(
         "type_name",
-        &StringData::new(ParameterId::PID_TYPE_NAME, name),
+        &StringData::new(ParameterId::PID_TYPE_NAME, name.to_string()),
       )
       .unwrap();
     }
@@ -1041,30 +1042,32 @@ impl<'a> BuiltinDataSerializer<'a> {
       pub max_blocking_time: Duration,
     }
 
-    if let Some(rel) = self.reliability { match rel {
-      Reliability::BestEffort => {
-        let data = ReliabilityBestEffortData {
-          reliability_kind: ReliabilityKind::BEST_EFFORT,
-          max_blocking_time: Duration::from(StdDuration::from_secs(0)),
-        };
-        s.serialize_field(
-          "reliability",
-          &QosData::new(ParameterId::PID_RELIABILITY, &data),
-        )
-        .unwrap();
+    if let Some(rel) = self.reliability {
+      match rel {
+        Reliability::BestEffort => {
+          let data = ReliabilityBestEffortData {
+            reliability_kind: ReliabilityKind::BEST_EFFORT,
+            max_blocking_time: Duration::from(StdDuration::from_secs(0)),
+          };
+          s.serialize_field(
+            "reliability",
+            &QosData::new(ParameterId::PID_RELIABILITY, &data),
+          )
+          .unwrap();
+        }
+        Reliability::Reliable { max_blocking_time } => {
+          let data = ReliabilityBestEffortData {
+            reliability_kind: ReliabilityKind::RELIABLE,
+            max_blocking_time,
+          };
+          s.serialize_field(
+            "reliability",
+            &QosData::new(ParameterId::PID_RELIABILITY, &data),
+          )
+          .unwrap();
+        }
       }
-      Reliability::Reliable { max_blocking_time } => {
-        let data = ReliabilityBestEffortData {
-          reliability_kind: ReliabilityKind::RELIABLE,
-          max_blocking_time,
-        };
-        s.serialize_field(
-          "reliability",
-          &QosData::new(ParameterId::PID_RELIABILITY, &data),
-        )
-        .unwrap();
-      }
-    } }
+    }
   }
 
   fn add_ownership<S: Serializer>(&self, s: &mut S::SerializeStruct) {
@@ -1081,35 +1084,37 @@ impl<'a> BuiltinDataSerializer<'a> {
       pub parameter_length: u16,
       pub kind: OwnershipKind,
     }
-    if let Some(own) = self.ownership { match own {
-      Ownership::Shared => {
-        s.serialize_field(
-          "ownership",
-          &OwnershipData {
-            parameter_id: ParameterId::PID_OWNERSHIP,
-            parameter_length: 4,
-            kind: OwnershipKind::Shared,
-          },
-        )
-        .unwrap();
+    if let Some(own) = self.ownership {
+      match own {
+        Ownership::Shared => {
+          s.serialize_field(
+            "ownership",
+            &OwnershipData {
+              parameter_id: ParameterId::PID_OWNERSHIP,
+              parameter_length: 4,
+              kind: OwnershipKind::Shared,
+            },
+          )
+          .unwrap();
+        }
+        Ownership::Exclusive { strength } => {
+          s.serialize_field(
+            "ownership",
+            &OwnershipData {
+              parameter_id: ParameterId::PID_OWNERSHIP,
+              parameter_length: 4,
+              kind: OwnershipKind::Exclusive,
+            },
+          )
+          .unwrap();
+          s.serialize_field(
+            "ownership_strength",
+            &I32Data::new(ParameterId::PID_OWNERSHIP_STRENGTH, strength),
+          )
+          .unwrap();
+        }
       }
-      Ownership::Exclusive { strength } => {
-        s.serialize_field(
-          "ownership",
-          &OwnershipData {
-            parameter_id: ParameterId::PID_OWNERSHIP,
-            parameter_length: 4,
-            kind: OwnershipKind::Exclusive,
-          },
-        )
-        .unwrap();
-        s.serialize_field(
-          "ownership_strength",
-          &I32Data::new(ParameterId::PID_OWNERSHIP_STRENGTH, strength),
-        )
-        .unwrap();
-      }
-    } }
+    }
   }
 
   fn add_destination_order<S: Serializer>(&self, s: &mut S::SerializeStruct) {
@@ -1151,9 +1156,10 @@ impl<'a> BuiltinDataSerializer<'a> {
 
   fn add_history<S: Serializer>(&self, s: &mut S::SerializeStruct) {
     #[derive(Serialize, Clone)]
+    #[serde(rename_all = "SCREAMING_SNAKE_CASE")]
     enum HistoryKind {
-      KEEP_LAST,
-      KEEP_ALL,
+      KeepLast,
+      KeepAll,
     }
 
     #[derive(Serialize, Clone)]
@@ -1165,11 +1171,11 @@ impl<'a> BuiltinDataSerializer<'a> {
     if let Some(hs) = self.history {
       let history_data = match hs {
         History::KeepLast { depth } => HistoryData {
-          kind: HistoryKind::KEEP_LAST,
+          kind: HistoryKind::KeepLast,
           depth,
         },
         History::KeepAll => HistoryData {
-          kind: HistoryKind::KEEP_ALL,
+          kind: HistoryKind::KeepAll,
           depth: 0,
         },
       };
