@@ -1,4 +1,3 @@
-
 use serde::{Deserializer, de::DeserializeOwned};
 use std::marker::PhantomData;
 
@@ -14,7 +13,7 @@ pub struct PlCdrDeserializerAdapter<D> {
   phantom: PhantomData<D>,
 }
 
-const repr_ids: [RepresentationIdentifier; 4] = [
+const REPR_IDS: [RepresentationIdentifier; 4] = [
   // CDR_* are only added for random interoperability
   RepresentationIdentifier::CDR_BE,
   RepresentationIdentifier::CDR_LE,
@@ -28,7 +27,7 @@ where
   D: DeserializeOwned,
 {
   fn supported_encodings() -> &'static [RepresentationIdentifier] {
-    &repr_ids
+    &REPR_IDS
   }
 
   fn from_bytes(input_bytes: &[u8], encoding: RepresentationIdentifier) -> Result<D> {
@@ -39,7 +38,9 @@ where
       RepresentationIdentifier::PL_CDR_BE | RepresentationIdentifier::CDR_BE => {
         PlCdrDeserializer::from_big_endian_bytes::<D>(input_bytes)
       }
-      repr_id => Err(Error::Message(format!("Unknown representation identifier {:?}",repr_id
+      repr_id => Err(Error::Message(format!(
+        "Unknown representation identifier {:?}",
+        repr_id
       ))),
     }
   }
@@ -58,7 +59,9 @@ where
       RepresentationIdentifier::PL_CDR_BE | RepresentationIdentifier::CDR_BE => {
         PlCdrDeserializer::from_big_endian_bytes::<D::K>(input_bytes)
       }
-      repr_id => Err(Error::Message(format!("Unknown representation identifier {:?}",repr_id
+      repr_id => Err(Error::Message(format!(
+        "Unknown representation identifier {:?}",
+        repr_id
       ))),
     }
   }
@@ -96,7 +99,7 @@ impl<'de> PlCdrDeserializer<'de> {
     match self.endianness {
       RepresentationIdentifier::PL_CDR_LE | RepresentationIdentifier::PL_CDR_BE => {
         //let rep: Result<Vec<u8>> = to_bytes::<u16, LittleEndian>(&u16::from(self.endianness));
-        visitor.visit_bytes(&[self.endianness.to_bytes(), self.input].concat())
+        visitor.visit_bytes(&[&self.endianness.to_bytes(), self.input].concat())
       }
       e => Err(Error::Message(format!("Unsupported endianness {:?}", e))),
     }
