@@ -16,13 +16,13 @@ pub struct CacheChange {
   pub writer_guid: GUID,
   pub sequence_number: SequenceNumber,
   pub source_timestamp: Option<Timestamp>,
-  pub data_value: DDSData, 
+  pub data_value: DDSData,
 }
 
 #[cfg(test)]
 impl PartialEq for CacheChange {
   fn eq(&self, other: &Self) -> bool {
-      self.writer_guid == other.writer_guid
+    self.writer_guid == other.writer_guid
       && self.sequence_number == other.sequence_number
       && self.source_timestamp == other.source_timestamp
       && self.data_value == other.data_value
@@ -34,9 +34,14 @@ impl CacheChange {
     writer_guid: GUID,
     sequence_number: SequenceNumber,
     source_timestamp: Option<Timestamp>,
-    data_value: DDSData,  
+    data_value: DDSData,
   ) -> CacheChange {
-    CacheChange { writer_guid, sequence_number, source_timestamp, data_value, }
+    CacheChange {
+      writer_guid,
+      sequence_number,
+      source_timestamp,
+      data_value,
+    }
   }
 
   pub fn change_kind(&self) -> ChangeKind {
