@@ -88,7 +88,7 @@ use crate::{
         SubscriptionBuiltinTopicData, ReaderProxy, WriterProxy, PublicationBuiltinTopicData,
         TopicBuiltinTopicData,
       },
-      spdp_participant_data::SPDPDiscoveredParticipantData,
+      spdp_participant_data::SpdpDiscoveredParticipantData,
     },
   },
   messages::submessages::submessages::{Data, EntitySubmessage, SubmessageKind, SubmessageHeader},
@@ -120,22 +120,19 @@ use crate::messages::submessages::submessages::*;
 pub(crate) fn spdp_participant_msg() -> Message {
   let data = spdp_participant_data_raw();
 
-  let rtpsmsg = Message::read_from_buffer(data).unwrap();
-  rtpsmsg
+  Message::read_from_buffer(data).unwrap()
 }
 
 pub(crate) fn spdp_subscription_msg() -> Message {
   let data = spdp_subscription_data_raw();
 
-  let rtpsmsg = Message::read_from_buffer(data).unwrap();
-  rtpsmsg
+  Message::read_from_buffer(data).unwrap()
 }
 
 pub(crate) fn spdp_publication_msg() -> Message {
   let data = spdp_publication_data_raw();
 
-  let rtpsmsg = Message::read_from_buffer(data).unwrap();
-  rtpsmsg
+  Message::read_from_buffer(data).unwrap()
 }
 
 pub(crate) fn spdp_participant_msg_mod(port: u16) -> Message {
@@ -146,8 +143,8 @@ pub(crate) fn spdp_participant_msg_mod(port: u16) -> Message {
     match &mut submsg.body {
       SubmessageBody::Entity(v) => match v {
         EntitySubmessage::Data(d, _) => {
-          let mut participant_data: SPDPDiscoveredParticipantData =
-            PlCdrDeserializerAdapter::<SPDPDiscoveredParticipantData>::from_bytes(
+          let mut participant_data: SpdpDiscoveredParticipantData =
+            PlCdrDeserializerAdapter::<SpdpDiscoveredParticipantData>::from_bytes(
               &d.serialized_payload.as_ref().unwrap().value,
               RepresentationIdentifier::PL_CDR_LE,
             )
@@ -159,9 +156,10 @@ pub(crate) fn spdp_participant_msg_mod(port: u16) -> Message {
           participant_data.default_multicast_locators.clear();
 
           let datalen = d.serialized_payload.as_ref().unwrap().value.len() as u16;
-          data =
-            Bytes::from(to_bytes::<SPDPDiscoveredParticipantData, byteorder::LittleEndian>(&participant_data)
-              .unwrap());
+          data = Bytes::from(
+            to_bytes::<SpdpDiscoveredParticipantData, byteorder::LittleEndian>(&participant_data)
+              .unwrap(),
+          );
           d.serialized_payload.as_mut().unwrap().value = data.clone();
           submsglen =
             submsglen + d.serialized_payload.as_ref().unwrap().value.len() as u16 - datalen;
@@ -176,7 +174,7 @@ pub(crate) fn spdp_participant_msg_mod(port: u16) -> Message {
   tdata
 }
 
-pub(crate) fn spdp_participant_data() -> Option<SPDPDiscoveredParticipantData> {
+pub(crate) fn spdp_participant_data() -> Option<SpdpDiscoveredParticipantData> {
   let data = spdp_participant_data_raw();
 
   let rtpsmsg = Message::read_from_buffer(data).unwrap();
@@ -186,7 +184,7 @@ pub(crate) fn spdp_participant_data() -> Option<SPDPDiscoveredParticipantData> {
     match &submsg.body {
       SubmessageBody::Entity(v) => match v {
         EntitySubmessage::Data(d, _) => {
-          let particiapant_data: SPDPDiscoveredParticipantData =
+          let particiapant_data: SpdpDiscoveredParticipantData =
             PlCdrDeserializerAdapter::from_bytes(
               &d.serialized_payload.as_ref().unwrap().value,
               RepresentationIdentifier::PL_CDR_LE,
@@ -265,8 +263,12 @@ pub(crate) fn subscription_builtin_topic_data() -> Option<SubscriptionBuiltinTop
     })
     .build();
 
-  let sub_topic_data =
-    SubscriptionBuiltinTopicData::new(GUID::dummy_test_guid(EntityKind::WRITER_NO_KEY_USER_DEFINED), "some topic name", "RandomData", &qos);
+  let sub_topic_data = SubscriptionBuiltinTopicData::new(
+    GUID::dummy_test_guid(EntityKind::WRITER_NO_KEY_USER_DEFINED),
+    "some topic name".to_string(),
+    "RandomData".to_string(),
+    &qos,
+  );
 
   Some(sub_topic_data)
 }
@@ -341,11 +343,11 @@ pub(crate) fn topic_data() -> Option<TopicBuiltinTopicData> {
 
 pub(crate) fn content_filter_data() -> Option<ContentFilterProperty> {
   let content_filter = ContentFilterProperty {
-    contentFilteredTopicName: "tn".to_string(),
-    relatedTopicName: "rtn".to_string(),
-    filterClassName: "fcn".to_string(),
-    filterExpression: "fexp".to_string(),
-    expressionParameters: vec!["asdf".to_string(), "fdsas".to_string()],
+    content_filtered_topic_name: "tn".to_string(),
+    related_topic_name: "rtn".to_string(),
+    filter_class_name: "fcn".to_string(),
+    filter_expression: "fexp".to_string(),
+    expression_parameters: vec!["asdf".to_string(), "fdsas".to_string()],
   };
 
   Some(content_filter)
@@ -360,13 +362,13 @@ pub(crate) fn create_rtps_data_message<D: Serialize>(
 
   let mut rtps_message = Message::default();
   let prefix = GUID::dummy_test_guid(EntityKind::UNKNOWN_BUILT_IN);
-  let rtps_message_header = Header::new(prefix.guidPrefix);
+  let rtps_message_header = Header::new(prefix.guid_prefix);
   rtps_message.set_header(rtps_message_header);
 
   let serialized_payload = SerializedPayload {
     representation_identifier: RepresentationIdentifier::PL_CDR_LE,
     representation_options: [0; 2],
-    value: tdata.clone(),
+    value: tdata,
   };
   let data_message = Data {
     reader_id,
